SystemOrganization addCategory: #'Seaside-Tests-Functional'!

!GRPackage class methodsFor: '*seaside-tests-functional' stamp: 'jf 6/24/2010 11:15'!
seasideTestsFunctional
	^ self new
		name: 'Seaside-Tests-Functional';
		description: 'Functional Seaside test suite.';
		addDependency: 'Seaside-Environment';
		addDependency: 'Seaside-Widgets';
		addDependency: 'Seaside-Tests-Core';
		url: #seasideUrl;
		yourself! !

WATask subclass: #WADelegationTask
	instanceVariableNames: 'component1 component2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WADelegationTask methodsFor: 'accessing' stamp: 'lr 11/28/2008 16:40'!
children
	"Even if we component1 and component2, we have to return them as children as otherwise their decorations are not properly backtracked. See WADecorationTest."
	
	^ Array with: component1 with: component2! !

!WADelegationTask methodsFor: 'running' stamp: 'jf 12/19/2009 02:50'!
go
	self call: component1 onAnswer: [ :a1 |
		self call: component2 onAnswer: [ ] ]! !

!WADelegationTask methodsFor: 'initialization' stamp: 'lr 5/31/2008 15:53'!
initialize
	super initialize.
	component1 := WAFormDialog new
		addMessage: 'Step 1';
		yourself.
	component2 := WAFormDialog new
		addMessage: 'Step 2';
		yourself! !

WATask subclass: #WAEmptyTestTask
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAEmptyTestTask methodsFor: 'running' stamp: 'jf 2/8/2009 15:09'!
go
	"do nothing. I wonder what happens?"! !

WATask subclass: #WAFunctionalTaskTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAFunctionalTaskTest class methodsFor: 'testing' stamp: 'jf 2/1/2009 21:29'!
isFunctionalTest
	^ (self name = #WAFunctionalTaskTest) not! !

WAFunctionalTaskTest subclass: #WATaskErrorFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WATaskErrorFunctionalTest methodsFor: 'running' stamp: 'jf 12/29/2009 16:00'!
go
	self confirm: 'Raise an exception?' onAnswer: [ :answer |
		[ answer ifTrue: [ self error: 'foo' ] ]
			on: Error
			do: [ :error | self inform: 'Caught: ', error description onAnswer: [] ] ]! !

!WAPresenter class methodsFor: '*seaside-tests-functional' stamp: 'jf 2/1/2009 21:45'!
isFunctionalTest
	^ false! !

!GRPlatform methodsFor: '*seaside-tests-functional' stamp: 'jf 2/9/2010 01:30'!
seasideGarbageCollect
	"this is only needed by the functional tests"
	self subclassResponsibility! !

WAComponent subclass: #WAAllFunctionalTests
	instanceVariableNames: 'classes current'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAAllFunctionalTests commentStamp: 'pmm 2/18/2011 22:59' prior: 0!
If you want to see these examples:

/config app:
- add a new application named "tests"
- choose WAAllFunctionalTests as the root component
!

!WAAllFunctionalTests class methodsFor: 'testing' stamp: 'mb 1/31/2006 11:07'!
canBeRoot
	^ true! !

!WAAllFunctionalTests class methodsFor: 'accessing' stamp: 'jf 1/11/2010 12:40'!
description
	^ 'Seaside Functional Test Suite'! !

!WAAllFunctionalTests class methodsFor: 'initialization' stamp: 'jf 1/11/2010 12:42'!
initialize
	(WAAdmin register: self asApplicationAt: 'tests/functional')
		preferenceAt: #sessionClass put: WAExpirySession! !

!WAAllFunctionalTests methodsFor: 'accessing-readonly' stamp: 'lr 5/31/2008 11:15'!
children
	^ Array with: current contents! !

!WAAllFunctionalTests methodsFor: 'initialization' stamp: 'pmm 6/26/2011 13:36'!
initialRequest: aRequest 
	super initialRequest: aRequest.
	self requestContext consumer nextIfPresentDo: [ :className | 
		classes do: [ :each | 
			"#greaseString is required because of Symbol <-> String comparison"
			each name greaseString = className ifTrue: [ self selected: each ] ] ]! !

!WAAllFunctionalTests methodsFor: 'initialization' stamp: 'lr 5/31/2008 10:47'!
initialize
	super initialize.
	self initializeTests! !

!WAAllFunctionalTests methodsFor: 'initialization' stamp: 'jf 2/1/2009 21:40'!
initializeTests
	classes := (WAPresenter allSubclasses select: [ :each | each isFunctionalTest ])
				asSortedCollection: [ :a :b | a name < b name ].
	current := WAValueHolder with: classes first new! !

!WAAllFunctionalTests methodsFor: 'actions' stamp: 'lr 12/2/2008 08:33'!
next
	| nextIndex |
	nextIndex := self selectionIndex \\ classes size + 1.
	self selected: (classes at: nextIndex)
	! !

!WAAllFunctionalTests methodsFor: 'actions' stamp: 'lr 12/2/2008 08:33'!
previous
	| nextIndex |
	nextIndex := (self selectionIndex + classes size - 2 \\ classes size) + 1.
	self selected: (classes at: nextIndex)! !

!WAAllFunctionalTests methodsFor: 'rendering' stamp: 'jf 1/11/2010 12:43'!
renderContentOn: html
	html heading: self class description.
	html form: [
		html paragraph: [
			html anchor
				callback: [ self previous ];
				with: [ html html: '&larr;' ].
			html select
				list: classes;
				onChange: 'submit()';
				selected: self selected;
				labels: [ :value | value name ];
				callback: [ :value | self selected: value ].
			html anchor
				callback: [ self next ];
				with: [ html html: '&rarr;' ].
			html text: ' '; submitButton: 'Restart' ] ].
	html horizontalRule.
	html render: current contents! !

!WAAllFunctionalTests methodsFor: 'accessing' stamp: 'lr 12/2/2008 08:33'!
selected
	^ current contents class! !

!WAAllFunctionalTests methodsFor: 'accessing' stamp: 'lr 12/2/2008 08:33'!
selected: aClass
	current contents: aClass new.
	(current contents respondsTo: #parent:)
		ifTrue: [ current contents parent: self ]! !

!WAAllFunctionalTests methodsFor: 'private' stamp: 'pmm 9/1/2008 23:21'!
selectionIndex
	^classes indexOf: self selected! !

!WAAllFunctionalTests methodsFor: 'accessing-readonly' stamp: 'lr 5/31/2008 11:15'!
states
	^ Array with: current! !

!WAAllFunctionalTests methodsFor: 'updating' stamp: 'lr 12/2/2008 08:29'!
updateUrl: aUrl
	super updateUrl: aUrl.
	aUrl addToPath: self selected name! !

WAComponent subclass: #WAFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

WAFunctionalTest subclass: #WABatchFunctionalTest
	instanceVariableNames: 'batcher'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WABatchFunctionalTest methodsFor: 'accessing' stamp: 'avi 12/18/2004 18:33'!
children
	^ Array with: batcher! !

!WABatchFunctionalTest methodsFor: 'initialization' stamp: 'pmm 9/12/2006 18:10'!
initialize
	super initialize.
	batcher := WAAlphabeticBatchedList new items: Collection allSubclasses! !

!WABatchFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderContentOn: html
	html render: batcher.
	html unorderedList
		list: batcher batch! !

WAFunctionalTest subclass: #WAButtonFunctionalTest
	instanceVariableNames: 'input'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAButtonFunctionalTest methodsFor: 'initialization' stamp: 'pmm 7/28/2007 08:43'!
initialize
	super initialize.
	self input: 'a text'! !

!WAButtonFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/28/2007 08:37'!
input
	^input! !

!WAButtonFunctionalTest methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
input: aString
	input := aString! !

!WAButtonFunctionalTest methodsFor: 'rendering' stamp: 'pmm 7/28/2007 08:48'!
renderContentOn: html
	html form: [
		html div: [
			self renderInputOn: html.
			self renderSubmitOn: html.
			self renderResetOn: html.
			self renderPushOn: html ] ]! !

!WAButtonFunctionalTest methodsFor: 'rendering' stamp: 'pmm 7/28/2007 08:46'!
renderInputOn: html
	html table: [
		html tableRow: [
			html tableHeading: 'Value:'.
			html tableData: self input ].
		html tableRow: [
			html tableHeading: 'Input:'.
			html tableData: [
				html textInput
					on: #input of: self ] ] ]! !

!WAButtonFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderPushOn: html
	html heading level2 with: 'Push'.
	html paragraph: 'Clicking the button should not do anything.'.
	html button bePush; with: 'Push'! !

!WAButtonFunctionalTest methodsFor: 'rendering' stamp: 'lr 2/28/2008 11:54'!
renderResetOn: html
	html heading level2 with: 'Reset'.
	html paragraph: 'Clicking the button should not submit the form and reset the value in "Input"'.
	html button beReset; with: 'Reset'! !

!WAButtonFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderSubmitOn: html
	html heading level2 with: 'Submit'.
	html paragraph: 'Clicking the button should submit the form and update the value in "Value:" with the value in "Input"'.
	html button with: 'Submit'! !

WAFunctionalTest subclass: #WACallbackFunctionalTest
	instanceVariableNames: 'transcript'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WACallbackFunctionalTest methodsFor: 'accessing' stamp: 'lr 2/4/2009 11:05'!
append: aString
	transcript nextPutAll: aString; nextPut: Character cr! !

!WACallbackFunctionalTest methodsFor: 'initialization' stamp: 'lr 2/4/2009 08:02'!
initialize
	super initialize.
	transcript := WriteStream on: String new! !

!WACallbackFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 10:02'!
renderContentOn: html 
	html paragraph: 'Depending on the way the form is submitted the following actions should be triggered and logged:'.
	html orderedList list: #( 
		'Default: Text, Default'
		'Before: Text'
		'Before Submit: Text, Before Submit'
		'Before Cancel: Before Cancel'
		'After: Text'
		'After Submit: Text, After Submit'
		'After Cancel: After Cancel'
	).
	html form
		defaultAction: [ self append: 'Default' ] ;
		with: [
			html div: [
				"div for validation"
				html submitButton
					text: 'Before'.
				html submitButton
					callback:  [ self append: 'Before Submit' ];
					text: 'Before Submit'.
				html cancelButton
					callback:  [ self append: 'Before Cancel' ];
					text: 'Before Cancel'.
				html break.
				html textInput
					value: 'Some Text';
					callback: [ :value | self append: 'Text: ' , value ].
				html break.
				html submitButton
					text: 'After'.
				html submitButton
					callback:  [ self append: 'After Submit' ];
					text: 'After Submit'.
				html cancelButton
					callback:  [ self append: 'After Cancel' ];
					text: 'After Cancel' ] ].
	html preformatted: transcript contents.
	transcript reset! !

WAFunctionalTest subclass: #WACallbackSecurityFunctionalTest
	instanceVariableNames: 'letter number'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WACallbackSecurityFunctionalTest methodsFor: 'initialization' stamp: 'jf 10/8/2008 10:47'!
initialize
	super initialize.
	number := 1.
	letter := $A.! !

!WACallbackSecurityFunctionalTest methodsFor: 'rendering' stamp: 'pmm 6/26/2011 13:37'!
renderContentOn: html 
	self renderInstructionsOn: html.
	html form: [
		html div: [
			self renderNumberListOn: html.
			self renderLetterListOn: html.
			html submitButton ] ].
	html paragraph: 'This should always be a NUMBER: ' , number greaseString.
	html paragraph: 'This should always be a LETTER: ' , letter greaseString.
	html paragraph: [
		| url |
		url := html actionUrl greaseString.
		html anchor
			url: '#';
			onClick: 'swapCallbacks("' , url , '","letter-list", "number-list")';
			with: 'Try to break it' ]! !

!WACallbackSecurityFunctionalTest methodsFor: 'rendering' stamp: 'jf 10/8/2008 11:54'!
renderInstructionsOn: html
	html paragraph: 'This test requires JavaScript. The list boxes should behave normally when used with the submit button. The link will try to submit the value C to the number listbox and the value 3 to the letter list box.'.
	html paragraph: 'Current behaviour results in C and 3 being selected in the appropriate lists. What is essential, however, is only that the values are not selected in the wrong list because this might allow an attacker to trick seaside into running methods on the wrong objects.'.! !

!WACallbackSecurityFunctionalTest methodsFor: 'rendering' stamp: 'jf 10/8/2008 11:49'!
renderLetterListOn: html
	html select
		id: 'letter-list';
		size: 3;
		selected: letter;
		list: (Array with: $A with: $B with: $C);
		callback: [ :value | letter := value ]! !

!WACallbackSecurityFunctionalTest methodsFor: 'rendering' stamp: 'jf 10/8/2008 11:48'!
renderNumberListOn: html
	html select
		id: 'number-list';
		size: 3;
		selected: number;
		list: (Array with: 1 with: 2 with: 3);
		callback: [ :value | number := value ]! !

!WACallbackSecurityFunctionalTest methodsFor: 'accessing' stamp: 'jf 10/8/2008 11:47'!
script
^ '
function swapCallbacks(url, list1id, list2id) {
	list1 = document.getElementById(list1id);
	list2 = document.getElementById(list2id);
	
	document.location = url
		+ "&" + list1.name + "=" + list2.options[2].value
		+ "&" + list2.name + "=" + list1.options[2].value;
}
		
'! !

!WACallbackSecurityFunctionalTest methodsFor: 'accessing' stamp: 'jf 10/8/2008 10:45'!
states
	^ Array with: self! !

WAFunctionalTest subclass: #WACanvasTableFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WACanvasTableFunctionalTest methodsFor: 'samples' stamp: 'lr 10/28/2007 14:42'!
entities
	^#(
		('non-breaking space' ('&nbsp;' '&#160;' '&#xA0;'))
		('ampersand' ('&amp;' '&#38;' '&#x26;'))
		('less than sign' ('&lt;' '&#60;' '&#x3C;'))
		('greater than sign' ('&gt;' '&#62;' '&#x3E;'))
		('euro sign' ('&euro;' '&#8364;' '&#x20AC;'))
	)! !

!WACanvasTableFunctionalTest methodsFor: 'samples' stamp: 'lr 10/28/2007 14:42'!
exchangeRates
	^#(
		('EUR' 1.70)
		('USD' 1.30)
		('DKK' 23.36)
		('SEK' 19.32)
	)! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/16/2007 17:11'!
renderContentOn: html
	html div
		class: 'wacanvastabletest';
		with: [
			self renderEntityTableOn: html.
			self renderCurrencyTableOn: html ]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:43'!
renderCurrencyTableBodyOn: html
	html tableBody 
		title: 'Table body';
		with: [
			self exchangeRates do: [:each |
				html tableRow: [
					html tableHeading: each first.
					html tableData align: 'char'; character: $.;
						with: each second ] ] ]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:43'!
renderCurrencyTableHeadOn: html
	html tableHead
		title: 'Table header';
		with: [
			html tableRow: [
				html tableHeading: 'Currency'.
				html tableHeading: 'Rate' ] ]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:43'!
renderCurrencyTableOn: html
	html table
 		summary: 'This table shows exchange rates against the Swiss Franc';
		with: [
			html tableCaption: 'Currencies against Swiss Franc (CHF)'.
			html tableColumnGroup.
			html tableColumnGroup width: '100px'; align: 'char'; character: $..
			self renderCurrencyTableHeadOn: html.
			self renderCurrencyTableBodyOn: html ]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderEntityTableBodyOn: html
	html tableBody: [
		self entities do: [:eachEntity |
			html tableRow: [
				html tableData scope: 'row';
					with: eachEntity first.
				eachEntity second do: [ :each |
					html tableData: each ].
				eachEntity second do: [ :each |
					html tableData align: 'center';
						with: [ html html: each ] ] ] ] ]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderEntityTableColumnGroupsOn: html
	html tableColumnGroup.
	html tableColumnGroup span: 3.
	html tableColumnGroup span: 3; align: 'center'! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:43'!
renderEntityTableFootOn: html
	html tableFoot: [
		html tableRow: [
			html tableData align: 'center'; colSpan: 7;
				with: '5 entities shown' ] ]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderEntityTableHeadOn: html
	html tableHead: [
		html tableRow: [
			#('Character' 'Entity' 'Decimal' 'Hex') do: [:each |
				html tableHeading scope: 'col'; rowSpan: 2;
					with: each].
			html tableHeading scope: 'colgroup'; colSpan: 3;
				with: 'Rendering in Your Browser'
		].
		html tableRow: [
			#('Entity' 'Decimal' 'Hex') do: [:each |
				html tableHeading scope: 'col'; with: each]
		].
	]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:43'!
renderEntityTableOn: html
	html table
 		summary: 'This table gives the character entity reference,
                decimal character reference, and hexadecimal character
                reference for 8-bit Latin-1 characters, as well as the
                rendering of each in your browser.';
		with: [
			html tableCaption: 'HTML 4.0 entities'.
			self renderEntityTableColumnGroupsOn: html.
			self renderEntityTableHeadOn: html.
			self renderEntityTableFootOn: html.
			self renderEntityTableBodyOn: html ]! !

!WACanvasTableFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/16/2007 17:23'!
style
	^'
.wacanvastabletest table {
	border-collapse: collapse;
	border:1px solid black;
	margin:0px auto; /* center */
}

.wacanvastabletest caption {
	margin:0px auto; /* center */
}
.wacanvastabletest caption {
	font-weight: bold;
	padding: 0.5em 0 1em 0;
}
.wacanvastabletest td, .wacanvastabletest th {
	padding: 3px;
	border:1px solid black;
}
'! !

WAFunctionalTest subclass: #WAContextFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAContextFunctionalTest methodsFor: 'rendering' stamp: 'pmm 11/8/2008 13:14'!
renderContentOn: html
	self renderExplanationOn: html.
	html table: [
		self renderLabel: 'Codec:' value:  self requestContext codec on: html.
		self renderLabel: 'Session:' value:  self requestContext session on: html.
		self renderLabel: 'Application:' value:  self requestContext application on: html.
		self renderLabel: 'Request:' value:  self requestContext request on: html.
		self renderLabel: 'Response:' value:  self requestContext response on: html.
		self renderRequestHandlersOn: html.
		self renderPropertiesOn: html ]! !

!WAContextFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/30/2008 16:38'!
renderExplanationOn: html

	html paragraph: 'The purpose of this test is to make sure WAContext and WACurrentContext work correctly. For each label you should see the print string of one or several matching objects. For the ''Request Handlers'' the first object should be a WASession or subclass, the second a WAApplication and then one or several WADispatchers matching the path.'! !

!WAContextFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/30/2008 16:15'!
renderLabel: aString value: anObject on: html
	html tableRow: [
		html tableHeading: aString.
		html tableData: anObject ]! !

!WAContextFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 13:45'!
renderPropertiesOn: html
	html tableRow: [
		html tableHeading: 'Properties:'.
		html tableData: [
			| properties |
			properties := self requestContext properties.
			properties isEmpty ifFalse: [
				html definitionList: [
					properties keysAndValuesDo: [ :key :value |
						html definitionTerm: key.
						html definitionData: value ] ] ] ] ]! !

!WAContextFunctionalTest methodsFor: 'rendering' stamp: 'lr 4/9/2008 10:43'!
renderRequestHandlersOn: html 
	html tableRow: [
		html tableHeading: 'Request Handlers:'.
		html tableData: [ 
			html orderedList list: self requestContext handlers ] ]! !

WAFunctionalTest subclass: #WACookieFunctionalTest
	instanceVariableNames: 'firstKey firstValue firstPath secondKey secondValue secondPath'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WACookieFunctionalTest methodsFor: 'actions' stamp: 'pmm 1/22/2009 22:48'!
addBoth
	self requestContext response addCookie: self firstCookie.
	self requestContext response addCookie: self secondCookie.
	
	self resetFirst.
	self resetSecond! !

!WACookieFunctionalTest methodsFor: 'actions' stamp: 'pmm 1/22/2009 22:48'!
addFirst
	self requestContext response addCookie: self firstCookie.
	
	self resetFirst! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'lr 4/9/2008 10:43'!
cookies
	^ self requestContext request cookies! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'lr 4/9/2008 10:43'!
firstCookie
	^self requestContext newCookie
		key: self firstKey;
		value: self firstValue;
		path: self firstPath;
		yourself! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:11'!
firstKey
	^ firstKey! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:30'!
firstKey: aString
	firstKey := aString! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:11'!
firstPath
	^ firstPath! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:30'!
firstPath: aString
	firstPath := aString! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:11'!
firstValue
	^ firstValue! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:30'!
firstValue: aString
	firstValue := aString! !

!WACookieFunctionalTest methodsFor: 'initialization' stamp: 'jf 11/3/2009 01:17'!
initialize
	super initialize.
	self firstPath: self application url pathString.
	self secondPath: self application url pathString.! !

!WACookieFunctionalTest methodsFor: 'actions' stamp: 'pmm 1/22/2009 22:15'!
remove: aCookie
	self requestContext response deleteCookie: aCookie! !

!WACookieFunctionalTest methodsFor: 'rendering-explanation' stamp: 'pmm 4/5/2008 16:52'!
renderCombiningOn: html
	html listItem: 'Setting both cookies should work in Kom and is broken in Swazoo.'! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 4/5/2008 14:05'!
renderContentOn: html
	self renderExplanationOn: html.

	html form: [
		html table: [
			self renderHeadingsOn: html.
			self renderCookiesOn: html.
			self renderInputOn: html ] ]! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/22/2008 20:20'!
renderCookiesOn: html
	self cookies do: [ :each |
		html tableRow: [
			html tableData: each key.
			html tableData: each value.
			html tableData: each path.
			html tableData: each domain.
			html tableData: each ports.
			html tableData: [
				html submitButton
					callback: [ self remove: each ];
					text: 'remove' ] ] ]! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 4/5/2008 14:08'!
renderExplanationOn: html
	html unorderedList: [
		self renderFirefoxOn: html.
		self renderSafariOn: html.
		self renderOperaOn: html.
		self renderRemoveOn: html ]! !

!WACookieFunctionalTest methodsFor: 'rendering-explanation' stamp: 'pmm 4/5/2008 14:08'!
renderFirefoxOn: html
	html listItem: 'On Firefox the path is not supposed to work. But if you look under Settings -> Cookies the cookie should be saved with the correct path.'! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/22/2008 20:18'!
renderHeadingsOn: html
	html tableRow: [
		html tableHeading: 'Key'.
		html tableHeading: 'Value'.
		html tableHeading: 'Path'.
		html tableHeading: 'Domain'.
		html tableHeading: 'Ports'.
		html tableHeading ]! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 4/4/2008 22:25'!
renderInputFirstOn: html
	html tableRow: [
		self renderInputForCookie: #first on: html.
		html tableData: [
			html submitButton
				on: #addFirst of: self ] ]! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 4/4/2008 22:22'!
renderInputForCookie: aSymbol on: html
	html tableData: [
		html textInput
			on: (aSymbol, #Key) asSymbol of: self ].
	html tableData: [
		html textInput
			on: (aSymbol, #Value) asSymbol of: self ].
	html tableData: [
		html textInput
			on: (aSymbol, #Path) asSymbol of: self ].
	html tableData.
	html tableData.! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 4/4/2008 22:27'!
renderInputOn: html
	self renderInputFirstOn: html.
	self renderInputSecondOn: html! !

!WACookieFunctionalTest methodsFor: 'rendering' stamp: 'pmm 4/4/2008 22:25'!
renderInputSecondOn: html
	html tableRow: [
		self renderInputForCookie: #second on: html.
		html tableData: [
			html submitButton
				on: #addBoth of: self ] ]! !

!WACookieFunctionalTest methodsFor: 'rendering-explanation' stamp: 'pmm 4/5/2008 14:08'!
renderOperaOn: html
	html listItem: 'Opera is supposed to work perfectly.'! !

!WACookieFunctionalTest methodsFor: 'rendering-explanation' stamp: 'pmm 4/5/2008 17:46'!
renderRemoveOn: html
	html listItem: 'Removing should work on Firefox and Safari but only if the path is unchanged. On Opera it should delete the value and the path.'! !

!WACookieFunctionalTest methodsFor: 'rendering-explanation' stamp: 'pmm 4/5/2008 14:07'!
renderSafariOn: html
	html listItem: 'On Safari the path is not supposed to work. But if you look under Preferences -> Security -> Show Cookies the cookie should be saved with the correct path.'! !

!WACookieFunctionalTest methodsFor: 'private' stamp: 'jf 11/3/2009 01:17'!
resetFirst
	self firstKey: nil.
	self firstValue: nil.
	self firstPath: self application url pathString! !

!WACookieFunctionalTest methodsFor: 'private' stamp: 'jf 11/3/2009 01:17'!
resetSecond
	self secondKey: nil.
	self secondValue: nil.
	self secondPath: self application url pathString! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'lr 4/9/2008 10:42'!
secondCookie
	^self requestContext newCookie
		key: self secondKey;
		value: self secondValue;
		path: self secondPath;
		yourself! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:12'!
secondKey
	^ secondKey! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:31'!
secondKey: aString
	secondKey := aString! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:12'!
secondPath
	^ secondPath! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:31'!
secondPath: aString
	secondPath := aString! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:12'!
secondValue
	^ secondValue! !

!WACookieFunctionalTest methodsFor: 'accessing' stamp: 'pmm 4/4/2008 22:31'!
secondValue: aString
	secondValue := aString! !

WAFunctionalTest subclass: #WADateSelectorFunctionalTest
	instanceVariableNames: 'beginDate endDate beginTime endTime beginDAT endDAT'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WADateSelectorFunctionalTest methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
children
	^(OrderedCollection new)
		add: beginDate;
		add: endDate;
		add: beginTime;
		add: endTime;
		add: beginDAT;
		add: endDAT;
		yourself! !

!WADateSelectorFunctionalTest methodsFor: 'actions' stamp: 'pmm 6/26/2011 13:40'!
computeDuration
	| dateDiff |
	dateDiff := (endDAT dateAndTime asDate - beginDAT dateAndTime asDate) days.
	dateDiff isZero 
		ifFalse: [
			self 
				inform: dateDiff greaseString , ' day(s)'
				onAnswer: [ ] ]
		ifTrue: [
			self 
				inform: (endDAT dateAndTime asTime subtractTime: beginDAT dateAndTime asTime) asSeconds greaseString , ' second(s)'
				onAnswer: [ ] ]! !

!WADateSelectorFunctionalTest methodsFor: 'initialization' stamp: 'dkh 3/7/2008 11:24'!
initialize
	super initialize.
	beginDate := WADateSelector new.
	endDate := WADateSelector new.
	endDate date: (Date today addDays: 1).

	beginTime := WATimeSelector new.
	beginTime time: Time now.
	endTime := WATimeSelector new.
	endTime time: (beginTime time addSeconds: 3600).

	beginDAT := WADateTimeSelector new.
	endDAT := WADateTimeSelector new.
	endDAT dateAndTime: beginDAT dateAndTime + 1 days + 1 hours! !

!WADateSelectorFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderContentOn: html

	self renderDateSelectorsOn: html.
	html horizontalRule.
	self renderTimeSelectorsOn: html.
	html horizontalRule.
	self renderDateTimeSelectorsOn: html! !

!WADateSelectorFunctionalTest methodsFor: 'rendering' stamp: 'pmm 6/26/2011 14:09'!
renderDateSelectorsOn: html 
	html heading
		level3;
		with: 'Dates'.
	html form: [
		html table: [
			html tableRow: [
				html
					tableData: 'From';
					tableData: beginDate ].
			html tableRow: [
				html
					tableData: 'To';
					tableData: endDate ] ].
		html div: [
			html submitButton
				callback: [
					self 
						inform: (endDate date - beginDate date) days greaseString , ' day(s)'
						onAnswer: [ ] ];
				text: 'Compute duration' ] ]! !

!WADateSelectorFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 13:47'!
renderDateTimeSelectorsOn: html
	html heading level3; with: 'Dates and Times'.
	html form: [
		html table: [
			html tableRow: [
				html tableData: 'From'; tableData: beginDAT ].
			html tableRow: [
				html tableData: 'To'; tableData: endDAT ] ].
		html div: [
			html submitButton
				callback: [ self computeDuration ];
				text: 'Compute duration' ] ]! !

!WADateSelectorFunctionalTest methodsFor: 'rendering' stamp: 'pmm 6/26/2011 14:09'!
renderTimeSelectorsOn: html 
	html heading
		level3;
		with: 'Times'.
	html form: [
		html table: [
			html tableRow: [
				html
					tableData: 'From';
					tableData: beginTime ].
			html tableRow: [
				html
					tableData: 'To';
					tableData: endTime ] ].
		html div: [
			html submitButton
				callback: [
					self 
						inform: (endTime time subtractTime: beginTime time) asSeconds greaseString , ' seconds(s)'
						onAnswer: [ ] ];
				text: 'Compute duration' ] ]! !

WAFunctionalTest subclass: #WADateTimeFunctionalTest
	instanceVariableNames: 'date time message'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WADateTimeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:22'!
date
	^date! !

!WADateTimeFunctionalTest methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
date: aDate
	date := aDate! !

!WADateTimeFunctionalTest methodsFor: 'rendering' stamp: 'lr 12/27/2008 18:05'!
renderContentOn: html
	self renderDateTimeOn: html.
	self renderDeadDateTimeOn: html! !

!WADateTimeFunctionalTest methodsFor: 'rendering' stamp: 'lr 8/2/2010 18:47'!
renderDateTimeOn: html 
	html heading
		level3;
		with: 'Form with #dateInput and #timeInput'.
	html form
		defaultAction: [ message := 'Default action: ' , date greaseString , ' ' , time greaseString ];
		with: [
			html div: [
				" use #callback: and #with: "
				html dateInput
					callback: [ :value | self date: value ];
					with: self date.
				html space: 10.
				" use #on:of: "
				html timeInput
					withSeconds;
					on: #time of: self.
				html break.
				html text: message.
				html break.
				html submitButton 
					callback: [ message := 'Button action: ' , date greaseString , ' ' , time greaseString ] ] ]! !

!WADateTimeFunctionalTest methodsFor: 'rendering' stamp: 'lr 8/2/2010 18:50'!
renderDeadDateTimeOn: html
	html heading
		level: 3;
		with: 'Div with #dateInput and #timeInput, no callback'.
	html form: [
		html div: [
			html dateInput value: Date today.
			html space: 10.
			html timeInput withSeconds; with: Time now.
			html break.
			html withLineBreaks: 'The year portion of the date should be visible.
				The seconds portion of the time should be visible.
				Exactly one date and one time selector should be visible.' ] ]! !

!WADateTimeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:23'!
time
	^time! !

!WADateTimeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/19/2006 19:23'!
time: aTime
	time := aTime! !

WAFunctionalTest subclass: #WADelayFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WADelayFunctionalTest methodsFor: 'actions' stamp: 'lr 1/24/2009 21:10'!
go
	self show: (WAComponent new
		addMessage: '3 seconds';
		addDecoration: (WADelayedAnswerDecoration new delay: 3);
		yourself)! !

!WADelayFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/2/2007 00:20'!
renderContentOn: html
	html paragraph: 'Clicking the following anchor should replace it with the message "3 seconds" for 3 seconds and then restore it.'.
	html paragraph: [
		html anchor
			callback: [ self go ];
			with: 'Start' ]! !

WAFunctionalTest subclass: #WADelegationFunctionalTest
	instanceVariableNames: 'task'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WADelegationFunctionalTest commentStamp: 'lr 5/31/2008 10:58' prior: 0!
http://code.google.com/p/seaside/issues/detail?id=71!

!WADelegationFunctionalTest methodsFor: 'accessing' stamp: 'lr 5/31/2008 11:18'!
children
	^ Array with: task! !

!WADelegationFunctionalTest methodsFor: 'initialization' stamp: 'jf 12/19/2009 02:37'!
initialize
	super initialize.
	task := WADelegationTask new! !

!WADelegationFunctionalTest methodsFor: 'rendering' stamp: 'jf 10/22/2008 16:13'!
renderContentOn: html
	html orderedList: [
		html listItem: 'Click button of Step 1'.
		html listItem: 'Click back-button'.
		html listItem: 'Click button of Step 1'.
		html listItem: 'Click button of Step 2' ].
	html paragraph: 'Step 1 and Step 2 should have consistent number of visible presenters. Especially there should never be two WAAnswerDecorations.'.
	
	html heading level: 2; with: 'Application'.
	html render: task.
	
	html heading level: 2; with: 'Visible Presenters'.
	html table: [
		html tableRow: [
			html tableHeading: 'Presenter'.
			html tableHeading.
			html tableHeading: 'Next'.
			html tableHeading ].
		self visiblePresentersDo: [ :each |
			html tableRow: [
				html tableData: each printString.
				html tableData: each identityHash.
				html tableData: (each isDecoration
					ifTrue: [ each next printString ]
					ifFalse: [ each decoration printString ]).
				html tableData: (each isDecoration
					ifTrue: [ each next identityHash ]
					ifFalse: [ each decoration identityHash ]) ] ] ]! !

WAFunctionalTest subclass: #WAEncodingFunctionalTest
	instanceVariableNames: 'urlencoded multipart get'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAEncodingFunctionalTest commentStamp: 'pmm 2/18/2011 23:00' prior: 0!
A WAEncodingFunctionalTest test whether Seaside correctly handles non-ASCII strings. Unfortunately due to differences in server setup and source code encodings this test requires manual interaction.
!

!WAEncodingFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/9/2008 19:46'!
get
	^ get! !

!WAEncodingFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/9/2008 19:47'!
get: aString
	get := aString! !

!WAEncodingFunctionalTest methodsFor: 'initialization' stamp: 'pmm 5/9/2008 19:52'!
initialize
	super initialize.
	self urlencoded: 'urlencoded'.
	self multipart: 'multipart'.
	self get: 'get'! !

!WAEncodingFunctionalTest methodsFor: 'accessing' stamp: 'pmm 6/22/2007 20:21'!
multipart
	^multipart! !

!WAEncodingFunctionalTest methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
multipart: aString
	multipart := aString! !

!WAEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 8/24/2010 06:57'!
renderCharacterByCharacter: aString on: html
	"Display aString character by character, but wrap each character into a span so it ends up individually in the output stream. If the codec does not convert to the internal encoding of Smalltalk the result is broken. Either choose an appropriate codec or be aware of the concequences."
	
	self requestContext codec name = '(none)'
	"Character by character rendering will fail for the NullCoded in case of multi byte characters. Don't test it."
		ifTrue: [ ^self ].
	aString 	do: [ :each | html span: each ]! !

!WAEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 13:49'!
renderClassName: aString on: html 
	aString isNil ifTrue: [ ^ self ].
	html paragraph: [
		html strong: 'Class: '.
		html text: aString class name ]! !

!WAEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/11/2008 16:41'!
renderContentOn: html
	self renderExplanationOn: html.
	self renderUrlencodedOn: html.
	self renderMultipartOn: html.
	self renderGetOn: html! !

!WAEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 09:49'!
renderExplanationOn: html
	html unorderedList: [
		html listItem: [
			html text: 'Go to the '.
			html anchor
				url: 'http://www.columbia.edu/kermit/utf8.html';
				with: 'UTF-8 Sampler'.
			html text: ' and select some "foreign" text.' ].
		html listItem: 'Copy and paste it into the urlencoded text field below and click the submit button.'.
		html listItem: 'The heading, textfield, character field and submitt button should all display the text without any error.'.
		html listItem: 'Submit again without changing anything, again everything should display normally.'.
		html listItem: 'Repeat this process for the multipart field. Make sure to pick at least every of these languages: German, Czech, Korean.' ]! !

!WAEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 09:50'!
renderGetOn: html

	html heading level2;
		with: 'GET'.
	html heading level3;
		with: self get.
	self renderCharacterByCharacter: self get on: html.
	html form
		get;
		with: [
			html div: [
				html textInput
					on: #get of: self.
				html submitButton
					text: self get ] ].
	self renderClassName: self get on: html! !

!WAEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 09:50'!
renderMultipartOn: html

	html heading level2;
		with: 'Multipart'.
	html heading level3;
		with: self multipart.
	self renderCharacterByCharacter: self multipart on: html.
	html form
		multipart;
		with: [
			html div: [
				html textInput
					on: #multipart of: self.
				html submitButton
					text: self multipart ] ].
	self renderClassName: self multipart on: html! !

!WAEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 09:50'!
renderUrlencodedOn: html

	html heading level2;
		with: 'Urlencoded'.
	html heading level3;
		with: self urlencoded.
	self renderCharacterByCharacter: self urlencoded on: html.
	html form: [
		html div: [
			html textInput
				on: #urlencoded of: self.
			html submitButton
				text: self urlencoded ] ].
	self renderClassName: self urlencoded on: html! !

!WAEncodingFunctionalTest methodsFor: 'accessing' stamp: 'pmm 7/2/2007 00:04'!
urlencoded
	^urlencoded! !

!WAEncodingFunctionalTest methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
urlencoded: aString
	urlencoded := aString! !

WAFunctionalTest subclass: #WAExceptionFunctionalTest
	instanceVariableNames: 'renderError'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAExceptionFunctionalTest methodsFor: 'accessing' stamp: 'jf 3/4/2009 10:43'!
exceptionFilter
	^ self application filters detect: [ :each | each isExceptionFilter ] ifNone: [ nil ]! !

!WAExceptionFunctionalTest methodsFor: 'initialization' stamp: 'jf 2/8/2009 22:25'!
initialize
	super initialize.
	renderError := false! !

!WAExceptionFunctionalTest methodsFor: 'actions' stamp: 'lr 1/25/2010 23:30'!
raiseDeprecated
	self 
		greaseDeprecatedApi: 'WAExceptionFunctionalTest>>#raiseDeprecated'
		details: 'Test action phase deprecation.'.
	self 
		inform: 
			[ :html | 
			self 
				greaseDeprecatedApi: 'WAExceptionFunctionalTest>>#raiseDeprecated'
				details: 'Test render phase deprecation.'.
			html paragraph: 'To be displayed' ]
		onAnswer: [ ]! !

!WAExceptionFunctionalTest methodsFor: 'actions' stamp: 'jf 12/19/2009 02:53'!
raiseError
	| result |
	result := self error: 'Test Error'.
	self 
		inform: 'Signalling the error returned: ' , result greaseString
		onAnswer: [ ]! !

!WAExceptionFunctionalTest methodsFor: 'actions' stamp: 'jf 12/19/2009 02:53'!
raiseHalt
	| context |
	self halt.
	"You should be able to step over the following line and have the current request context
	successfully stored in the variable.
	You should also (ideally anyway, it works on Squeak) be able to Inspect the value of
	'self requestContext' in the Debugger and get a result.
	Finally, you should be able to restart this method in the Debugger and do the above
	again successfully."
	context := self requestContext.
	self inform: 'To be displayed' onAnswer: [ ]! !

!WAExceptionFunctionalTest methodsFor: 'actions' stamp: 'jf 12/19/2009 02:54'!
raiseResumable
	1 / 0.
	self inform: 'To be displayed' onAnswer: [ ]! !

!WAExceptionFunctionalTest methodsFor: 'actions' stamp: 'jf 12/19/2009 02:54'!
raiseWarning
	self notify: 'Test Warning'.
	self inform: 'To be displayed' onAnswer: [ ]! !

!WAExceptionFunctionalTest methodsFor: 'rendering' stamp: 'jf 2/21/2009 15:21'!
renderContentOn: html
	html div class: 'errorTest'; with: [
		self renderHandlerConfigurationOn: html.
		self renderPartsOn: html ]! !

!WAExceptionFunctionalTest methodsFor: 'rendering' stamp: 'lr 11/12/2008 08:11'!
renderDeprecatedOn: html 
	html heading: 'Deprecated'.
	html paragraph: 'The link should cause a deprecated warning to appear in the toolbar. Clicking on the link should display a single action and a single render deprecation.'.
	html anchor
		callback: [ self raiseDeprecated ];
		with: 'Raise deprecated'! !

!WAExceptionFunctionalTest methodsFor: 'rendering' stamp: 'dkh 11/20/2009 14:33'!
renderErrorOn: html 
	html heading: 'Error'.
	html paragraph: 'Behaviour is exception-handler-dependent. If a Debugger is opened, closing the debugger window should at least result in the socket being closed and should not lock the session. Proceeding from the Debugger should be handled gracefully but behaviour is platform-dependent. On Pharo and GemStone, you should see an error page in the browser. On VW, you should see a message indicating that nil was returned.'.
	html anchor
		callback: [ self raiseError ];
		with: 'Raise error'! !

!WAExceptionFunctionalTest methodsFor: 'rendering' stamp: 'jf 11/10/2008 10:12'!
renderHaltOn: html 
	html heading: 'Halt'.
	html paragraph: 'Behaviour is handler-dependent. In most cases, a Debugger should open in in the image. There are comments in the #raiseHalt method suggesting other things that should be tested from within the Debugger. Clicking on proceed should display the information message "To be displayed".'.
	html anchor
		callback: [ self raiseHalt ];
		with: 'Halt execution'! !

!WAExceptionFunctionalTest methodsFor: 'rendering' stamp: 'jf 3/4/2009 11:08'!
renderHandlerConfigurationOn: html
	| attribute filter |
	filter := self exceptionFilter.
	filter isNil ifTrue: [
		html paragraph: 'Exception handler configuration attribute not found!!'.
		^ self ].
	attribute := filter configuration attributeAt: #exceptionHandler.

	html form: [
		html div: [
			html select
				beOptional;
				optionalLabel: '(inherited default)';
				list: attribute options asArray;
				selected: (filter configuration at: attribute key);
				callback: [ :value | 
					value isNil
						ifTrue: [ filter configuration removeExpressionAt: attribute key ifAbsent: [] ]
						ifFalse: [ filter configuration takeValue: value forAttribute: attribute ] ].
			html submitButton with: 'Set Handler' ] ]! !

!WAExceptionFunctionalTest methodsFor: 'rendering' stamp: 'jf 2/21/2009 15:21'!
renderPartsOn: html
	self renderHaltOn: html.
	self renderErrorOn: html.
	self renderRenderErrorOn: html.
	self renderResumableErrorOn: html.
	self renderWarningOn: html.
	self renderDeprecatedOn: html! !

!WAExceptionFunctionalTest methodsFor: 'rendering' stamp: 'jf 2/8/2009 22:29'!
renderRenderErrorOn: html
	"This is really hacky. We're trying to avoid depending on Flow here. Don't try this
	at home kids."
	renderError ifTrue: [ renderError := false. self error: 'Error during rendering.' ].
	
	html heading: 'Error During Rendering'.
	html paragraph: 'This will trigger an error during the next render phase.'.
	html anchor
		callback: [ renderError := true ];
		with: 'Raise error'! !

!WAExceptionFunctionalTest methodsFor: 'rendering' stamp: 'jf 11/10/2008 10:14'!
renderResumableErrorOn: html 
	html heading: 'Resumable error'.
	html paragraph: 'Behaviour is handler-dependent. If a Debugger is opened, clicking on proceed should display the message "To be displayed".'.
	html anchor
		callback: [ self raiseResumable ];
		with: 'Raise zero divide'! !

!WAExceptionFunctionalTest methodsFor: 'rendering' stamp: 'dkh 11/20/2009 14:41'!
renderWarningOn: html 
	html heading: 'Warning'.
	html paragraph: 'In Pharo and GemStone the warning test works the same as the resumable error test.'.
	html paragraph: 'In VisualWorks the warning test works the same as the halt test.'.
	html anchor
		callback: [ self raiseWarning ];
		with: 'Raise warning'! !

WAFunctionalTest subclass: #WAExpiryFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAExpiryFunctionalTest methodsFor: 'rendering' stamp: 'YM 5/22/2010 22:45'!
redirect
	"we need to build the url we redirect to because we just expired the session in this test"
	| url |
	url := self application url.
	url addAllToPath: self requestContext consumer upToEnd.
	^ self requestContext responseGenerator
		redirectTo: url;
		respond! !

!WAExpiryFunctionalTest methodsFor: 'rendering' stamp: 'pmm 7/3/2011 15:58'!
renderActionsOn: html
	html
		paragraph: [ 
			html anchor
				url: (self application url with: self class name);
				with: 'New Session'.
			html break.
			html anchor
				callback: [ self session unregister . self redirect ];
				with: 'Expire'.
			html break.
			html anchor
				callback: [ WAExpirySession resetCounters ];
				with: 'Reset Counters'.
			html break.
			html anchor
				callback: [ GRPlatform current seasideGarbageCollect ];
				with: 'Garbage Collect'.
			html break.
			html anchor
				callback: [ 
					self application clear.
					GRPlatform current seasideGarbageCollect.
					self redirect ];
				with: 'Clear Cache'.
			html break.
			html anchor
				callback: [ 
					self application clear.
					WAExpirySession resetCounters.
					GRPlatform current seasideGarbageCollect.
					self redirect ];
				with: 'Reset All' ]! !

!WAExpiryFunctionalTest methodsFor: 'rendering' stamp: 'pmm 7/31/2007 07:17'!
renderContentOn: html
	self renderStatsOn: html.
	self renderActionsOn: html! !

!WAExpiryFunctionalTest methodsFor: 'rendering' stamp: 'lr 12/2/2008 08:35'!
renderStatsOn: html
	html table: [
		html tableRow: [
			html tableHeading: 'Total session instances'.
			html tableData: WAExpirySession allInstances size ].
		html tableRow: [
			html tableHeading: 'Cached session instances for this Application'.
			html tableData: self application cache size ].
		html tableRow: [
			html tableHeading: 'Total component instances'.
			html tableData: self class allInstances size ].
		html tableRow: [
			html tableHeading: 'Sessions created'.
			html tableData: WAExpirySession created ].
		html tableRow: [
			html tableHeading: 'Sessions unregistered'.
			html tableData: WAExpirySession unregistered ] ]! !

WAFunctionalTest subclass: #WAFilterFunctionalTest
	instanceVariableNames: 'child'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAFilterFunctionalTest methodsFor: 'actions' stamp: 'jf 12/19/2009 02:54'!
authentication
	| filter |
	"We could use #filterWith:during: but that requires Flow."
	filter := WAAuthenticationFilter new
			authenticator: self;
			yourself.
	self session addFilter: filter.
	child inform: 'Congratulations, you have been authenticated. The new filter should be visible in the list above. Clicking on "ok" should remove the filter. Using the back button and hitting refresh should show the filter again.' onAnswer: [ self session removeFilter: filter ]! !

!WAFilterFunctionalTest methodsFor: 'accessing' stamp: 'lr 8/31/2008 15:12'!
children
	^ Array with: child! !

!WAFilterFunctionalTest methodsFor: 'initialization' stamp: 'lr 8/31/2008 15:12'!
initialize
	super initialize.
	child := WAComponent new! !

!WAFilterFunctionalTest methodsFor: 'actions' stamp: 'jf 12/19/2009 02:54'!
protector
	| filter |
	"We could use #filterWith:during: but that requires Flow."
	filter := WAProtectionFilter new.
	self session addFilter: filter.
	child inform: 'Open this page on a different computer by copying the complete URL to a machine with a different IP address. Seaside should reply with a forbidden message. Closing this dialog should remove the filter.' onAnswer: [ self session removeFilter: filter ]! !

!WAFilterFunctionalTest methodsFor: 'rendering' stamp: 'lr 8/31/2008 15:16'!
renderActionsOn: html
	html paragraph: [
		html anchor
			callback: [ self authentication ];
			with: 'Basic Authentication'.
		html text: ' (admin/seaside)'.
		html break.
		html anchor
			callback: [ self protector ];
			with: 'Session Protector' ].
	html horizontalRule.
	html paragraph: self children! !

!WAFilterFunctionalTest methodsFor: 'rendering' stamp: 'lr 8/31/2008 15:08'!
renderContentOn: html
	self renderFiltersOn: html.
	self renderActionsOn: html! !

!WAFilterFunctionalTest methodsFor: 'rendering' stamp: 'lr 11/4/2008 09:22'!
renderFiltersOn: html
	html paragraph: 'Below a list of filters wrapping the current session:'.
	html orderedList list: self session filters! !

!WAFilterFunctionalTest methodsFor: 'private' stamp: 'lr 8/31/2008 15:01'!
verifyPassword: aPasswordString forUser: aUserString
	^ aUserString = 'admin' and: [ aPasswordString = 'seaside' ]! !

!WAFunctionalTest class methodsFor: 'testing' stamp: 'jf 2/1/2009 21:28'!
isFunctionalTest
	^ (self name = #WAFunctionalTest) not! !

WAFunctionalTest subclass: #WAHomeFunctionalTest
	instanceVariableNames: 'main'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAHomeFunctionalTest methodsFor: 'accessing' stamp: 'avi 10/19/2004 15:53'!
children
	^ Array with: main! !

!WAHomeFunctionalTest methodsFor: 'initialization' stamp: 'lr 2/28/2008 09:54'!
initialize
	super initialize.
	main := self message: 'Root Component'! !

!WAHomeFunctionalTest methodsFor: 'accessing' stamp: 'lr 2/28/2008 09:54'!
message: aString
	^ WAComponent new
		addMessage: aString;
		yourself! !

!WAHomeFunctionalTest methodsFor: 'rendering' stamp: 'lr 1/24/2009 21:11'!
renderContentOn: html
	html paragraph: 'Clicking home should always bring back the root component.'.
	html paragraph: [
		html anchor
			callback: [ main show: (self message: 'Called Component') ];
			with: 'call'.
		html space.
		html anchor
			callback: [ main home ];
			with: 'home' ].
	html render: main! !

WAFunctionalTest subclass: #WAIframeFunctionalTest
	instanceVariableNames: 'calendar'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAIframeFunctionalTest methodsFor: 'accessing' stamp: 'jf 10/18/2008 22:22'!
children
	^ Array with: calendar! !

!WAIframeFunctionalTest methodsFor: 'initialization' stamp: 'jf 10/18/2008 22:12'!
initialize
	super initialize.
	calendar := WAMiniCalendar new! !

!WAIframeFunctionalTest methodsFor: 'rendering' stamp: 'jf 10/18/2008 22:25'!
renderContentOn: html
	html paragraph: 'With #contents:'.
	html iframe
		contents: calendar.
	html paragraph: 'With #url:'.
	html iframe
		url: (WATestingFiles / #samplePng).
	html paragraph: 'With #document:'.
	html iframe
		document: WATestingFiles default samplePng
		mimeType: 'image/png'! !

!WAIframeFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
style
	^ 'iframe {
	border: 1px solid gray;
	width: 100%;
}'! !

WAFunctionalTest subclass: #WAImageMapFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAImageMapFunctionalTest methodsFor: 'rendering' stamp: 'pmm 2/8/2011 21:29'!
renderContentOn: html 
	html heading
		level: 3;
		with: 'A byte array with server side map (ismap)'.
	html paragraph: 'Click anywhere on the Style Editor icon and you should get informed about the position where you clicked.'.
	html paragraph: [
		html map
			title: 'Click anywhere on the style editor icon';
			callback: [ :aPoint | 
				self 
					inform: 'Clicked at ' , aPoint greaseString , ' on the Style Editor Icon'
					onAnswer: [ ] ];
			with: [
				html image
					altText: 'Style Editor Icon';
					width: '40%';
					url: WATestingFiles / #samplePng ] ]! !

WAFunctionalTest subclass: #WAInputGetFunctionalTest
	instanceVariableNames: 'inputElements'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAInputGetFunctionalTest methodsFor: 'accessing' stamp: 'pmm 8/31/2008 17:59'!
children
	^Array with: inputElements! !

!WAInputGetFunctionalTest methodsFor: 'initialization' stamp: 'pmm 8/31/2008 17:59'!
initialize
	super initialize.
	inputElements := WAInputElementContainer new! !

!WAInputGetFunctionalTest methodsFor: 'rendering' stamp: 'pmm 12/28/2008 09:25'!
renderContentOn: html
	self renderExplanationOn: html.
	html form
		get;
		with: [
			html table: inputElements.
			html div: [
				"div for validation"
				html submitButton ] ]! !

!WAInputGetFunctionalTest methodsFor: 'rendering' stamp: 'lr 2/22/2009 15:09'!
renderExplanationOn: html
	html paragraph: 'This form uses a HTTP GET request. The upload is not supposed to work.'! !

WAFunctionalTest subclass: #WAInputPostFunctionalTest
	instanceVariableNames: 'inputElements hasBody ran'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAInputPostFunctionalTest methodsFor: 'accessing' stamp: 'pmm 9/19/2007 06:55'!
children
	^Array with: inputElements! !

!WAInputPostFunctionalTest methodsFor: 'initialization' stamp: 'pmm 9/6/2009 12:57'!
initialize
	super initialize.
	inputElements := WAInputElementContainer new.
	ran := false! !

!WAInputPostFunctionalTest methodsFor: 'actions' stamp: 'pmm 9/6/2009 13:16'!
readRequestBody
	ran := true.
	hasBody := self requestContext request rawBody notNil! !

!WAInputPostFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/6/2009 13:00'!
renderContentOn: html
	self renderExplanationOn: html.
	html form: [
		html table: inputElements.
		html div: [
			self renderRequestBodyOn: html.
			"div for validation"
			html submitButton ] ]! !

!WAInputPostFunctionalTest methodsFor: 'rendering' stamp: 'lr 2/22/2009 15:10'!
renderExplanationOn: html
	html paragraph: 'This form uses an URL-encoded POST request. The upload is not supposed to work.'! !

!WAInputPostFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/6/2009 13:02'!
renderRequestBodyOn: html
	html hiddenInput
		callback: [ self readRequestBody ].
	html strong: 'Request Body:'.
	ran
		ifTrue: [ html text: (hasBody ifTrue: [ 'Success' ] ifFalse: [ 'Fail' ]) ]
		ifFalse: [ html text: 'Not Run' ].
	html break! !

WAFunctionalTest subclass: #WAInputPostMultipartFunctionalTest
	instanceVariableNames: 'inputElements hasBody ran'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAInputPostMultipartFunctionalTest methodsFor: 'accessing' stamp: 'pmm 9/19/2007 06:55'!
children
	^Array with: inputElements! !

!WAInputPostMultipartFunctionalTest methodsFor: 'initialization' stamp: 'pmm 9/6/2009 13:08'!
initialize
	super initialize.
	inputElements := WAInputElementContainer new.
	ran := false! !

!WAInputPostMultipartFunctionalTest methodsFor: 'actions' stamp: 'jf 2/15/2010 20:27'!
readRequestBody
	ran := true.
	hasBody := self requestContext request rawBody notNil! !

!WAInputPostMultipartFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/6/2009 13:09'!
renderContentOn: html
	self renderExplanationOn: html.
	html form
		multipart;
		with: [
			html table: inputElements.
			html div: [
				self renderRequestBodyOn: html.
				"div for validation"
				html submitButton ] ]! !

!WAInputPostMultipartFunctionalTest methodsFor: 'rendering' stamp: 'lr 2/22/2009 15:11'!
renderExplanationOn: html
	html paragraph: 'This form uses a multipart POST request. The upload is supposed to accept a file.'! !

!WAInputPostMultipartFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/6/2009 13:08'!
renderRequestBodyOn: html
	html hiddenInput
		callback: [ self readRequestBody ].
	html strong: 'Request Body:'.
	ran
		ifTrue: [ html text: (hasBody ifTrue: [ 'Success' ] ifFalse: [ 'Fail' ]) ]
		ifFalse: [ html text: 'Not Run' ].
	html break! !

WAFunctionalTest subclass: #WALotsaLinksFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WALotsaLinksFunctionalTest methodsFor: 'rendering' stamp: 'pmm 6/26/2011 14:13'!
renderContentOn: html 
	self renderExplanationOn: html.
	html unorderedList: [
		1 to: 5000 do: [ :each | 
			html listItem: [
				html anchor
					name: each greaseString;
					callback: [
						self 
							inform: each
							onAnswer: [ self session jumpToAnchor: each greaseString ] ];
					with: each ] ] ]! !

!WALotsaLinksFunctionalTest methodsFor: 'rendering' stamp: 'obi 3/10/2009 20:15'!
renderExplanationOn: html
	html paragraph: [
		html text: 'This test serves three purposes:'.
		html orderedList: [
			html listItem: 'First it is a regression test, earlier versions of Seaside could only handle a limited number of callbacks per page. The oldest links (low numbers) would use their callback. Clicking on any link should display this number with a button.'.
			html listItem: 'Second it serves as a raw rendering speed benchmark.'.
			html listItem: 'Third it tests WASession >> #jumpToAnchor:. After confirming the number you should return to the page and be automatically at the place where the link is.' ] ]! !

WAFunctionalTest subclass: #WAManyTasksFunctionalTest
	instanceVariableNames: 'tasks selection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAManyTasksFunctionalTest methodsFor: 'actions' stamp: 'jf 2/5/2009 08:54'!
addTask
	selection contents notNil ifTrue: [ tasks add: selection contents new ]! !

!WAManyTasksFunctionalTest methodsFor: 'hooks' stamp: 'jf 2/5/2009 08:43'!
children
	^ tasks! !

!WAManyTasksFunctionalTest methodsFor: 'initialization' stamp: 'jf 12/19/2009 02:37'!
initialize
	super initialize.
	tasks := OrderedCollection new.
	selection := WAValueHolder new.
	tasks add: WADelegationTask new! !

!WAManyTasksFunctionalTest methodsFor: 'rendering' stamp: 'jf 12/14/2009 21:26'!
renderContentOn: html
	html form: [ 
		html div: [
			html paragraph: 'Adding WAEmptyTestTask is expected to cause an infinite recursion and should raise an exception.'.
			html select
				list: (self taskClasses asSortedCollection: [ :a :b | a name <= b name ]);
				on: #contents of: selection.
			html submitButton
				callback: [ self addTask ];
				with: 'Add'.
			html submitButton
				callback: [ self showTask ];
				with: 'Show' ] ].
	self renderTasksOn: html! !

!WAManyTasksFunctionalTest methodsFor: 'rendering' stamp: 'lr 2/28/2009 22:29'!
renderTasksOn: html
	tasks do: [ :each |
		html div: [
			html div: each.
			html anchor
				callback: [ tasks remove: each ];
				with: '(remove task)' ] ]! !

!WAManyTasksFunctionalTest methodsFor: 'actions' stamp: 'jf 12/14/2009 21:26'!
showTask
	selection contents notNil ifTrue: [ self show: selection contents new ]! !

!WAManyTasksFunctionalTest methodsFor: 'initialization' stamp: 'jf 2/8/2009 10:50'!
states
	^ Array with: tasks! !

!WAManyTasksFunctionalTest methodsFor: 'accessing' stamp: 'lr 7/25/2011 18:46'!
taskClasses
	^ WATask allSubclasses select: [ :each | each subclasses isEmpty ]! !

WAFunctionalTest subclass: #WAMiniCalendarFunctionalTest
	instanceVariableNames: 'calendar'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAMiniCalendarFunctionalTest methodsFor: 'accessing' stamp: 'pmm 9/11/2007 06:49'!
children
	^Array with: calendar! !

!WAMiniCalendarFunctionalTest methodsFor: 'initialization' stamp: 'pmm 9/11/2007 06:48'!
initialize
	super initialize.
	calendar := WAMiniCalendar new! !

!WAMiniCalendarFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 14:16'!
renderContentOn: html
	html render: calendar.

	html div: [
		html strong: 'selected:'.
		html space.
		html render: calendar date ]! !

WAFunctionalTest subclass: #WAModelFunctionalTest
	instanceVariableNames: 'state user pass test'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAModelFunctionalTest methodsFor: 'actions' stamp: 'jf 12/19/2009 02:55'!
logoff
	state := #OFF.
	test ifTrue: [ self inform: 'Logged off' onAnswer: [ ] ]! !

!WAModelFunctionalTest methodsFor: 'actions' stamp: 'jf 12/19/2009 02:55'!
logon
	user isEmptyOrNil
		ifTrue:
			[ self inform: 'Nope !!' onAnswer: [ ] ]
		ifFalse:
			[ state := #ON.
			test ifTrue: [ self inform: 'Logged on' onAnswer: [ ] ] ]! !

!WAModelFunctionalTest methodsFor: 'accessing' stamp: 'mb 2/9/2006 15:04'!
pass
	"Answer the value of pass"

	^ pass! !

!WAModelFunctionalTest methodsFor: 'accessing' stamp: 'mb 2/9/2006 15:04'!
pass: anObject
	"Set the value of pass"

	pass := anObject! !

!WAModelFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 09:59'!
renderButtonOn: html
	| action |
	action := state == #ON ifTrue: [ #logoff ] ifFalse: [ #logon ].
	html div: [
		"div for validation"
		html submitButton
			on: action of: self ]! !

!WAModelFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:48'!
renderContentOn: html
	html form
		id: 'myform';
		with: [
			html table: [
				self renderUsernameOn: html.
				self renderPasswordOn: html.
				self renderFeedbackOn: html ].
			html div: [
				self renderButtonOn: html ] ]! !

!WAModelFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/15/2007 19:49'!
renderFeedbackOn: html
	html tableRow: [
		html tableData: [
			html label
				for: #withFeedback;
				with: 'With Feedback:' ].
		html tableData: [
			html checkbox
				id: #withFeedback;
				on: #test of: self ] ]! !

!WAModelFunctionalTest methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderPasswordOn: html
	html tableRow: [
		html tableData: [
			html label
				for: #pass;
				with: 'Password:' ].
		html tableData: [
			html passwordInput
				id: #pass;
				on: #pass of: self ] ]! !

!WAModelFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/15/2007 19:52'!
renderUsernameOn: html
	html tableRow: [
		html tableData: [
			html label
				for: #userid;
				with: 'Username:' ].
		html tableData: [
			html textInput
				id: #userid;
				on: #user of: self ] ]! !

!WAModelFunctionalTest methodsFor: 'accessing' stamp: 'mb 2/9/2006 15:04'!
test
	"Answer the value of test"

	^ test! !

!WAModelFunctionalTest methodsFor: 'accessing' stamp: 'mb 2/9/2006 15:04'!
test: anObject
	"Set the value of test"

	test := anObject! !

!WAModelFunctionalTest methodsFor: 'accessing' stamp: 'mb 2/9/2006 15:10'!
user
	"Answer the value of user"

	^ user! !

!WAModelFunctionalTest methodsFor: 'accessing' stamp: 'mb 2/9/2006 15:10'!
user: anObject
	"Set the value of user"

	user := anObject! !

WAFunctionalTest subclass: #WAParameterFunctionalTest
	instanceVariableNames: 'wasExecuted values'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAParameterFunctionalTest commentStamp: 'pmm 2/18/2011 23:01' prior: 0!
A WAParameterFunctionalTest tests whether GET and POST fields are merged in WARequest >> #fields.!

!WAParameterFunctionalTest methodsFor: 'accessing' stamp: 'jf 2/15/2010 02:08'!
actionUrlFor: html
	| url |
	url := html actionUrl copy.
	url
		addField: self parameterName
		value: self firstParameterValue.
	^url! !

!WAParameterFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/11/2008 12:18'!
firstParameterValue
	^'firstValue'! !

!WAParameterFunctionalTest methodsFor: 'initialization' stamp: 'pmm 5/11/2008 12:14'!
initialize
	super initialize.
	wasExecuted := false! !

!WAParameterFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/11/2008 12:15'!
parameterName
	^'parameter'! !

!WAParameterFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/11/2008 12:39'!
renderContentOn: html
	self renderExplanationOn: html.
	wasExecuted
		ifTrue: [ self renderExecutedOn: html ]
		ifFalse: [ self renderNotExecutedOn: html ]! !

!WAParameterFunctionalTest methodsFor: 'rendering' stamp: 'jf 2/22/2010 11:39'!
renderExecutedOn: html
	html strong: (self wasSuccessful ifTrue: [ 'success' ] ifFalse: [ 'fail' ])! !

!WAParameterFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/11/2008 12:38'!
renderExplanationOn: html
	html paragraph: 'This test makes sure the server passes both GET and POST paramters to Seaside. Simply hit ''run test'' and ''success'' should be displayed. If ''fail'' is displayed or ''run test'' is displayed again then the test has failed.'! !

!WAParameterFunctionalTest methodsFor: 'rendering' stamp: 'pmm 8/31/2008 15:23'!
renderNotExecutedOn: html
	html form
		action: (self actionUrlFor: html);
		with: [
		 	html div: [
				html hiddenInput
					name: self parameterName;
					value: self secondParameterValue.
				html submitButton
					callback: [ self runTest ];
					text: 'run test' ] ]! !

!WAParameterFunctionalTest methodsFor: 'actions' stamp: 'jf 2/15/2010 19:37'!
runTest
	values := self requestContext request fields allAt: self parameterName.
	wasExecuted := true! !

!WAParameterFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/11/2008 12:18'!
secondParameterValue
	^'secondValue'! !

!WAParameterFunctionalTest methodsFor: 'testing' stamp: 'jf 2/22/2010 11:39'!
wasSuccessful
	^ values notNil
		and: [ values isCollection
		and: [ values isString not
		and: [ values size = 2
		and: [ (values includes: self firstParameterValue)
		and: [ (values includes: self secondParameterValue) ] ] ] ] ]! !

WAFunctionalTest subclass: #WAParentFunctionalTest
	instanceVariableNames: 'parent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAParentFunctionalTest methodsFor: 'accessing' stamp: 'ab 5/12/2003 22:13'!
parent: aComponent
	parent := aComponent! !

!WAParentFunctionalTest methodsFor: 'rendering' stamp: 'pmm 7/16/2007 20:07'!
renderContentOn: html
	self renderExplanationOn: html.
	self renderSwapParentOn: html! !

!WAParentFunctionalTest methodsFor: 'rendering' stamp: 'jf 12/29/2009 15:56'!
renderExplanationOn: html
	html paragraph: 'This regression tests checks if #call:onAnswer: on the parent component works. If you click "swap parent" "Test passes!!" should appear without a tab panel.'! !

!WAParentFunctionalTest methodsFor: 'rendering' stamp: 'jf 12/19/2009 02:31'!
renderSwapParentOn: html
	html paragraph: [
		html anchor
			callback: [ self swap ];
			with: 'swap parent' ]! !

!WAParentFunctionalTest methodsFor: 'actions' stamp: 'lr 7/25/2011 18:48'!
swap
	parent inform: 'Test passes!!' onAnswer: [ ]! !

WAFunctionalTest subclass: #WAPathFunctionalTest
	instanceVariableNames: 'string'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAPathFunctionalTest methodsFor: 'rendering' stamp: 'jf 10/18/2008 22:40'!
renderContentOn: html
	string notNil ifTrue: [ html anchor name: string ].
	
	html paragraph: 'Whatever you submit below should be added to the URL both as a path element and a fragment (the part after #).'.
	html form: [
		html div: [
			html textInput on: #string of: self.
			html submitButton ] ]! !

!WAPathFunctionalTest methodsFor: 'accessing' stamp: 'jf 10/18/2008 22:38'!
string
	^ string! !

!WAPathFunctionalTest methodsFor: 'accessing' stamp: 'jf 10/18/2008 22:38'!
string: anObject
	string := anObject! !

!WAPathFunctionalTest methodsFor: 'updating' stamp: 'pmm 11/4/2008 21:12'!
updateUrl: aUrl 
	super updateUrl: aUrl.
	string isNil ifTrue: [ ^self ].
	
	aUrl addToPath: string.
	aUrl fragment: string! !

WAFunctionalTest subclass: #WAPerformanceFunctionalTest
	instanceVariableNames: 'duration referenceDict builder'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAPerformanceFunctionalTest class methodsFor: 'accessing' stamp: 'obi 5/21/2010 20:56'!
referenceDict
	| dict |
	dict := Dictionary new.
	dict at: #anchor put: 'Anchor Test' -> 1800.
	dict at: #script put: 'Script Test' -> 5300.
	dict at: #table put: 'Table Test' -> 5280.
	dict at: #lineBreak put: 'Line Break Test' -> 4550.
	dict at: #callback put: 'Callback Test' -> 2130.
	dict at: #form put: 'Form Test' -> 270.
	dict at: #id put: 'Generate ID''s Test' -> 4300.
	dict at: #seasideText put: 'Seaside Text Rendering Test' -> 6500.
	dict at: #nativeText put: 'Native Text Rendering Test' -> 26000.
	dict at: #seasideBR put: 'Seaside (br) Rendering Test' -> 23000.
	dict at: #nativeBR put: 'Native (br) Rendering Test' -> 78000.
	^dict! !

!WAPerformanceFunctionalTest methodsFor: 'initialization' stamp: 'as 2/6/2011 22:06'!
initialize
	super initialize.
	builder := WAHtmlCanvas builder! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:55'!
renderAnchorsOn: canvas
	self renderInline: [ :html | 
		html unorderedList: [
			html listItem: [
					html anchor
						name: 'name';
						callback: [ ];
						with: 'Anchor' ] ] ]
		factor: 1
		key: #anchor
		on: canvas
! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:55'!
renderBreakOn: canvas
	self
		renderInline: [ :html | html break ]
		factor: 1 / 50
		key: #seasideBR
		on: canvas! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:56'!
renderCallbackOn: canvas
	self
		renderInline: [ :html | 
			html button
				callback: [  ];
				with: '' ]
		key: #callback
		on: canvas! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'jf 9/30/2009 01:10'!
renderContentOn: html 
	duration := 0.
	referenceDict ifNil: [ referenceDict := self class referenceDict ].
	self renderExplanationOn: html.
	self renderAnchorsOn: html.
	self renderScriptOn: html.
	self renderTableOn: html.
	self renderLineBreaksOn: html.
	self renderCallbackOn: html.
	self renderFormOn: html.
	self renderIdTestOn: html.
	self renderTextOn: html.
	self renderHtmlTextOn: html.
	self renderBreakOn: html.
	self renderNativeBreakOn: html.
	html div
		class: 'result';
		with: 'Seaside Performance Index: ' , duration greaseString! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'obi 5/21/2010 21:01'!
renderExplanationOn: html
	html paragraph: 'Test rendering speed (Reference: Intel Core 2 Duo E6750, Seaside 3.0; Pharo 1.0, ~ 1400 SPI)'! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'pmm 6/26/2011 14:13'!
renderFormOn: canvas 
	self 
		renderInline: [ :html | 
			html form: [
				html button value: 'OK'.
				html fileUpload.
				html select
					list: #('a' 'b' );
					labels: [ :v | v greaseString ].
				html radioButton.
				html textInput
					size: 20;
					value: ''.
				html textArea
					rows: 3;
					columns: 17;
					value: ''.
				html checkbox value: true.
				html passwordInput value: 'pw' ] ]
		key: #form
		on: canvas! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:55'!
renderHtmlTextOn: canvas
	self
		renderInline: [ :html | html html: 'abcdefghijklmnopqrstuvwxyz&amp;0123456789' ]
		factor: 1 / 50
		key: #nativeText
		on: canvas! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:55'!
renderIdTestOn: canvas
	self
		renderInline: [ :html | 
			| id1 |
			id1 := html nextId.
			html span
				id: id1;
				with: id1.
			html break ]
		key: #id
		on: canvas! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'pmm 6/26/2011 14:14'!
renderInline: aBlock factor: factor key: key on: html 
	| startTime endTime count backColor anAssociation title referenceValue spi context document renderer stream runTime |
	count := 0.
	runTime := 200.
	anAssociation := referenceDict 
		at: key
		ifAbsent: [ 'Undefined' -> 100000 ].
	title := anAssociation key.
	referenceValue := anAssociation value.
	stream := WriteStream on: String new.
	document := builder documentClass 
		on: stream
		codec: builder codec.
	context := WARenderContext new.
	context document: document.
	context
		actionUrl: builder actionUrl;
		resourceUrl: builder resourceUrl.
	renderer := builder rendererClass context: context.
	builder 
		openDocument: document
		context: context.
	html div
		class: 'bench';
		with: [
			html heading: title.
			startTime := Time millisecondClockValue.
			endTime := startTime + runTime.
			[ Time millisecondClockValue < endTime ] whileTrue: [
				count := count + 1.
				renderer
					render: aBlock;
					flush ] ].
	builder closeDocument: document.
	spi := (count / referenceValue * (10000 / runTime)) rounded.
	backColor := spi > 100 
		ifTrue: [ '#5f5' ]
		ifFalse: [
			spi < 50 
				ifTrue: [ '#f55' ]
				ifFalse: [ '#55f' ] ].
	duration := duration + spi.
	html div
		style: 'float:left;padding:4px';
		with: [
			html big: spi greaseString , ' SPI'.
			html span
				class: 'iteration';
				with: '(' , count greaseString , ' iterations)'.
			html break.
			html div
				class: 'rect';
				style: 'background:' , backColor , ';width:' , (spi * 2) greaseString , 'px' ].
	html div style: 'clear:both'! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'obi 3/13/2009 21:09'!
renderInline: aBlock key: key on: html
	self renderInline: aBlock factor: 1 key: key on: html! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:56'!
renderLineBreaksOn: canvas
	self
		renderInline: [ :html |
			html withLineBreaks: 'a
			b
			c' ]
		key: #lineBreak
		on: canvas
		
	! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:56'!
renderNativeBreakOn: canvas
	self
		renderInline: [ :html | html html: '<br/>' ]
		factor: 1 / 50
		key: #nativeBR
		on: canvas! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:55'!
renderScriptOn: canvas
	self renderInline: [ :html | html script: 'self.close()' ] key: #script on: canvas! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:55'!
renderTableOn: canvas
	self
		renderInline: [ :html | html table: [ html tableRow: [ html tableData: 'data' ] ] ] 
		key: #table
		on: canvas! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:56'!
renderTextOn: canvas
	self
		renderInline: [ :html | html text: 'abcdefghijklmnopqrstuvwxyz&0123456789' ]
		factor: 1 / 50
		key: #seasideText
		on: canvas! !

!WAPerformanceFunctionalTest methodsFor: 'rendering' stamp: 'obi 5/21/2010 20:41'!
style
	^ 'h1 {margin:0;padding:0}
	div.bench {padding-left:4px;position:relative;height:38px;width:400px;border: 1px solid #ccc;overflow:hidden;float:left}
	div.result {margin:6px;color:#008aff;font-size:200%;font-weight:bold}
	span.iteration {margin-left:6px}
	div.rect {position:relative;border: 1px solid #ccc;;height:12px}
	'! !

WAFunctionalTest subclass: #WAPhraseElementsFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 14:57'!
renderAbbreviatedOn: html

	html heading level2; with: '<abbr>'.

	html paragraph: [
		html abbreviated
			title: 'World Wide Web';
			with: 'WWW' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 14:57'!
renderAcronymOn: html

	html heading level2; with: '<acronym>'.

	html paragraph: [
		html acronym
			title: 'Federal Bureau of Investigation';
			with: 'F.B.I.' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/2/2006 21:26'!
renderAddressOn: html

	html heading level2; with: '<address>'.

	html address: [
		#(
			'Newsletter editor'
			'J.R. Brown'
			'JimquickPost News, Jimquick, CT 01234'
			'Tel (123) 456 7890')
			do: [ :each | html text: each ]
			separatedBy: [ html break ] ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 14:58'!
renderCodeOn: html

	html heading level2; with: '<code>'.

	html paragraph: [
		html text: 'Expressions like '.
		html code: 'a[i++] + b[i++]'.
		html text: ' should not be used, since they cause undefined behavior' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/28/2007 10:46'!
renderContentOn: html
	self renderHarryOn: html.
	self renderAbbreviatedOn: html.
	self renderAcronymOn: html.
	self renderKeyboardInputOn: html.
	self renderVariableOn: html.
	self renderCodeOn: html.
	self renderDefinitionOn: html.
	self renderSampleOn: html.
	self renderAddressOn: html.
	self renderModificationOn: html! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 14:59'!
renderDefinitionOn: html

	html heading level2; with: '<dfn>'.

	html paragraph: [
		html definition: 'Ichthyology'.
		html text: ' is the branch of natural science which studies fish.' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 14:56'!
renderHarryOn: html

	html heading level2; with: '<cite>, <q>, <strong>'.

	html paragraph: [
		html text: 'As '.
		html citation: 'Harry S. Truman'.
		html text: ' said, '.
		html quote: 'The buck stops here.'.

		html break.

		html text: 'More information can be found in '.
		html citation: '[ISO-0000]'.
		html text: '.'.

		html break.

		html text: 'Please refer to the following reference number in future correspondence: '.
		html strong: '1-234-55' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 14:58'!
renderKeyboardInputOn: html

	html heading level2; with: '<kbd>'.

	html paragraph: [
		html text: 'Finally, type '.
		html keyboard: 'logout'.
		html text: ' and press the return key.' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/28/2007 10:48'!
renderModificationOn: html

	html heading level2; with: '<ins>, <del>'.

	html paragraph: [
		html text: 'A Sheriff can employ '.
		html deleted
			title: 'Changed as a result of the SECURE bill.';
			cite: 'http://www.w3.org/TR/html401/struct/text.html#edef-del';
			datetime: '1994-11-05T08:15:30-05:00';
			with: 3.
		html inserted
			title: 'Changed as a result of the SECURE bill.';
			cite: 'http://www.w3.org/TR/html401/struct/text.html#edef-del';
			datetime: '1994-11-05T08:15:30-05:00';
			with: 5.
		html text: ' deputies.' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 15:00'!
renderSampleOn: html

	html heading level2; with: '<samp>'.

	html paragraph: [
		html text: 'If you select the ''champion'' option, you will receive the message '.
		html sample: 'The monkey is not a caterpillar'.
		html text: '.' ]! !

!WAPhraseElementsFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/4/2008 14:58'!
renderVariableOn: html

	html heading level2; with: '<var>'.

	html paragraph: [
		html text: 'In the simplest case, the command for deleting a file in Unix is'.
		html break.
		html keyboard: 'rm'.
		html space.
		html variable: 'filename' ]! !

WAFunctionalTest subclass: #WAPopupFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAPopupFunctionalTest methodsFor: 'actions' stamp: 'lr 6/29/2009 22:36'!
calendarLoop
	self session presenter
		show: WAMiniCalendar new
		onAnswer: [ :answer | self requestContext closeThisPopup ]! !

!WAPopupFunctionalTest methodsFor: 'actions' stamp: 'obi 3/8/2009 17:50'!
popupCloseTest
	self session presenter show: WAPopupCloseTestComponent new! !

!WAPopupFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:58'!
renderContentOn: html
	html paragraph: [ 
		html popupAnchor
			callback: [ self calendarLoop ];
			with: 'popup'.
		html break.
		html popupAnchor
			extent: 300 @ 300;
			callback: [ self calendarLoop ];
			with: 'popup with extent'.
		html break.
		html popupAnchor
			position: 100 @ 100;
			callback: [ self calendarLoop ];
			with: 'popup with position'.
		html break.
		html popupAnchor
			location: true;
			callback: [ self calendarLoop ];
			with: 'popup with location'.
		html break.
		html popupAnchor
			resizable: false;
			callback: [ self calendarLoop ];
			with: 'popup not resizable'.
		html break.
		html popupAnchor
			resizable: false;
			extent: 300 @ 300;
			position: 50 @ 50;
			callback: [ self popupCloseTest ];
			with: 'popup with close button' ]! !

WAFunctionalTest subclass: #WARequestFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 11:31'!
renderAcceptCharsetFor: aRequest on: html
	html definitionTerm: 'Accept-Charset:'.
	self renderQualifiedValues: aRequest acceptCharset on: html! !

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 11:29'!
renderAcceptEncodingFor: aRequest on: html
	html definitionTerm: 'Accept-Encoding:'.
	self renderQualifiedValues: aRequest acceptEncoding on: html! !

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 11:27'!
renderAcceptFor: aRequest on: html
	html definitionTerm: 'Accept:'.
	self renderQualifiedValues: aRequest accept on: html! !

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 11:31'!
renderAcceptLanguageFor: aRequest on: html
	html definitionTerm: 'Accept-Language:'.
	self renderQualifiedValues: aRequest acceptLanguage on: html! !

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 14:21'!
renderContentOn: html
	| request |
	html paragraph: 'This tests whether the server delivers the remote address correctly and headers can be parsed correctly.'.
	request := self requestContext request.
	html definitionList: [
		self renderRemoteAddressFor: request on: html.
		self renderAcceptFor: request on: html.
		self renderAcceptCharsetFor: request on: html.
		self renderAcceptEncodingFor: request on: html.
		self renderAcceptLanguageFor: request on: html ]! !

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 13:09'!
renderQualifiedValue: aQualifiedValue on: html
	html listItem: [
		| quality |
		html render: aQualifiedValue value.
		quality := aQualifiedValue quality.
		quality = Float infinity
			ifTrue: [ html superscript: [ html html: '&infin;' ] ]
			ifFalse: [ html superscript: quality ] ]! !

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 11:35'!
renderQualifiedValues: aCollection on: html
	html definitionData: [
		aCollection isNil
			ifTrue: [ html text: 'N/A' ]
			ifFalse: [
				html orderedList: [
					aCollection do: [ :each |
						self renderQualifiedValue: each on: html ] ] ] ]! !

!WARequestFunctionalTest methodsFor: 'rendering' stamp: 'pmm 9/13/2008 11:15'!
renderRemoteAddressFor: aRequest on: html
	html definitionTerm: 'Remote Address:'.
	html definitionData: aRequest remoteAddress! !

WAFunctionalTest subclass: #WASvgFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WASvgFunctionalTest methodsFor: 'rendering' stamp: 'pmm 6/14/2009 13:11'!
renderContentOn: html
	html object
		type: 'image/svg+xml' seasideMimeType;
		width: 600;
		height: 800;
		standby: 'loading tiger';
		url: 'http://croczilla.com/bits_and_pieces/svg/samples/tiger/tiger.svg';
		with: 'Your browser doesn''t support SVG'! !

WAFunctionalTest subclass: #WATableReportFunctionalTest
	instanceVariableNames: 'report'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WATableReportFunctionalTest methodsFor: 'accessing' stamp: 'lr 8/6/2007 13:27'!
children
	^ Array with: report! !

!WATableReportFunctionalTest methodsFor: 'initialization' stamp: 'jf 12/19/2009 02:56'!
initialize
	super initialize.
	report := WATableReport new
		rows: WAComponent allSubclasses asArray;
		columns: (OrderedCollection new
			add: (WAReportColumn
				selector: #fullName title: 'Name'
				onClick: [ :each | self inform: each description onAnswer: [ ] ]);
			add: ((WAReportColumn
				selector: #canBeRoot title: 'Can Be Root')
				sortBlock: [ :a :b | a ]);
			add: (WAReportColumn
				renderBlock: [ :each :html | html emphasis: each description ]
				title: 'Description');
			yourself);
		rowColors: #(lightblue lightyellow);
		rowPeriod: 1;
		yourself! !

WAFunctionalTest subclass: #WATrailFunctionalTest
	instanceVariableNames: 'component trail'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WATrailFunctionalTest methodsFor: 'accessing' stamp: 'jf 11/4/2008 11:40'!
children
	^ Array with: trail with: component! !

!WATrailFunctionalTest methodsFor: 'initialization' stamp: 'jf 11/4/2008 11:45'!
initialize
	super initialize.
	component := WATrailTestComponent new.
	trail := WATrail on: component! !

!WATrailFunctionalTest methodsFor: 'rendering' stamp: 'lr 11/11/2008 22:59'!
renderContentOn: html
	html render: trail.
	html div: component! !

WAFunctionalTest subclass: #WATrailingSlashFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WATrailingSlashFunctionalTest methodsFor: 'private' stamp: 'jf 2/15/2010 02:08'!
baseUrlWithSlash: aBoolean 
	^ self application url
		addToPath: self class name greaseString;
		addField: 'slash'
			value: aBoolean greaseString;
		slash: aBoolean;
		yourself! !

!WATrailingSlashFunctionalTest methodsFor: 'rendering' stamp: 'pmm 8/15/2009 10:34'!
renderContentOn: html
	self renderExplanationOn: html.
	self renderLinksOn: html! !

!WATrailingSlashFunctionalTest methodsFor: 'rendering' stamp: 'pmm 8/15/2009 11:09'!
renderExplanationOn: html
	html paragraph: 'This tests whether the sever adapter correctly passes the tailing slash of the request URL to the request context.'.
	html paragraph: 'Click each of the links below, and the status should change from "not run" to "success".'! !

!WATrailingSlashFunctionalTest methodsFor: 'rendering' stamp: 'pmm 8/15/2009 10:58'!
renderLinksOn: html
	html table: [
		html tableRow: [
			html tableData: [
				self renderSlashSuccess: true on: html ].
			html tableData: [
				html anchor
				url: (self baseUrlWithSlash: true);
				with: 'With Slash' ] ].
		
		html tableRow: [
			html tableData: [
				self renderSlashSuccess: false on: html ].
			html tableData: [
				html anchor
				url: (self baseUrlWithSlash: false);
				with: 'Without Slash' ] ] ]! !

!WATrailingSlashFunctionalTest methodsFor: 'private' stamp: 'pmm 6/26/2011 14:27'!
renderSlashSuccess: aBoolean on: html 
	| request hasTrailingSlash expectedSlash |
	request := self requestContext request.
	hasTrailingSlash := request url slash.
	expectedSlash := request fields 
		at: 'slash'
		ifAbsent: [ nil ].
	expectedSlash isNil 
		ifTrue: [ html strong: 'not run' ]
		ifFalse: [
			aBoolean greaseString = expectedSlash 
				ifTrue: [
					hasTrailingSlash greaseString = expectedSlash 
						ifTrue: [ html strong: 'success' ]
						ifFalse: [ html strong: 'fail' ] ]
				ifFalse: [ html strong: 'not run' ] ]! !

WAFunctionalTest subclass: #WATreeFunctionalTest
	instanceVariableNames: 'selected tree'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WATreeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 3/9/2008 11:37'!
children
	^Array with: tree! !

!WATreeFunctionalTest methodsFor: 'initialization' stamp: 'pmm 3/9/2008 11:40'!
initialize
	super initialize.
	tree := WATree new
		root: Collection;
		labelBlock: [ :class | class name ];
		childrenBlock: [ :class | class subclasses ];
		selectBlock: [ :class | selected := class name ];
		canSelectBlock: [ :class | class subclasses notEmpty ];
		yourself! !

!WATreeFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/9/2008 11:47'!
renderContentOn: html
	self renderExplanationOn: html.
	self renderTreeOn: html! !

!WATreeFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/9/2008 11:46'!
renderExplanationOn: html
	html paragraph: [
		html text: 'This is a functional test for WATree.'.
		html orderedList: [
			html listItem: 'Clicking on ''+'' should expand a node'.
			html listItem: 'Clicking on ''-'' should collapse a node'.
			html listItem: 'Clicking on a node should display its name after ''Selected:'''.
			html listItem: 'Leaf nodes should not be clickable' ] ]! !

!WATreeFunctionalTest methodsFor: 'rendering' stamp: 'pmm 3/9/2008 11:46'!
renderTreeOn: html
	html strong: 'Selected:'.
	html render: selected.
	
	html render: tree! !

!WATreeFunctionalTest methodsFor: 'accessing' stamp: 'pmm 3/9/2008 11:37'!
states
	^Array with: self! !

WAFunctionalTest subclass: #WAUploadFunctionalTest
	instanceVariableNames: 'file'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAUploadFunctionalTest methodsFor: 'rendering' stamp: 'pmm 11/12/2009 07:19'!
renderContentOn: html
	html heading: 'Upload File'.
	self renderExplanationOn: html.
	self renderUploadOn: html.
	file isNil ifTrue: [ ^ self ].
	self renderDownloadLinksOn: html.
	self renderFileContentsOn: html! !

!WAUploadFunctionalTest methodsFor: 'rendering' stamp: 'pmm 10/31/2010 13:58'!
renderDownloadLinksOn: html
	html paragraph: [
		| contents contentType |
		self renderIsByteArray: file rawContents on: html.
		html break.
		contentType := file contentType.
		contents := (contentType isNil or: [ contentType isBinary ])
			ifTrue: [ file rawContents ]
			ifFalse: [
				"we don't use #contentsDecoded because no browser sends them because operating systems suck at files"
				file contentsDecodedUsing: 'ISO-8859-1' ].
		html anchor
			document: contents
				mimeType: file contentType
				fileName: file fileName;
			with: file fileName , ' (' , file contentType greaseString , ')'.
		html break.
		html anchor
			document: file rawContents;
			with: file fileName ]! !

!WAUploadFunctionalTest methodsFor: 'rendering' stamp: 'pmm 11/12/2009 07:19'!
renderExplanationOn: html
	html paragraph: 'If "fail: wrong contents of WAFile" shows up then that means the contents of the WAFile are a String but should be a ByteArray.'! !

!WAUploadFunctionalTest methodsFor: 'rendering' stamp: 'pmm 11/14/2009 15:05'!
renderFileContentsOn: html 
	file size <= 16r10000
		ifTrue: [ html preformatted: (file contentsDecodedUsing: 'ISO-8859-1') ]
		ifFalse: [
			html break.
			html text: 'file size is: ', file size greaseString, ' bytes' ]! !

!WAUploadFunctionalTest methodsFor: 'rendering' stamp: 'pmm 11/14/2009 14:57'!
renderIsByteArray: aCollection on: html
	aCollection isString ifTrue: [
		html strong: 'fail: raw contents of WAFile should be a ByteArray not a String' ]! !

!WAUploadFunctionalTest methodsFor: 'rendering' stamp: 'pmm 5/12/2008 10:14'!
renderUploadOn: html

	html form
		multipart;
		with: [
			html div: [
				"div for HTML validation"
				html fileUpload callback: [ :f | file := f ].
				html submitButton text: 'Load' ] ]! !

WAFunctionalTest subclass: #WAUrlEncodingFunctionalTest
	instanceVariableNames: 'input'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAUrlEncodingFunctionalTest methodsFor: 'initialization' stamp: 'pmm 5/12/2008 09:38'!
initialize
	super initialize.
	input := 'input'! !

!WAUrlEncodingFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/11/2008 13:02'!
input
	^input! !

!WAUrlEncodingFunctionalTest methodsFor: 'accessing' stamp: 'pmm 5/12/2008 09:36'!
input: aString
	input := aString! !

!WAUrlEncodingFunctionalTest methodsFor: 'accessing' stamp: 'jf 2/15/2010 01:50'!
parameter
	| fieldValue request urlValue |
	request := self requestContext request.
	fieldValue := request at: 'input' ifAbsent: [ nil ].
	urlValue := request url queryFields at: 'input' ifAbsent: [ nil ].
	^(urlValue = input and: [ fieldValue = input ])
		ifTrue: [ fieldValue ]
		ifFalse: [ 'fail!!' ]! !

!WAUrlEncodingFunctionalTest methodsFor: 'accessing' stamp: 'pmm 9/28/2008 20:40'!
path
	| path |
	path := self requestContext request url path last.
	^path = input
		ifTrue: [ path ]
		ifFalse: [ 'fail!!' ]! !

!WAUrlEncodingFunctionalTest methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:59'!
renderContentOn: html
	self renderExplanationOn: html.

	html form
		get;
		with: [
			html div: [
				html textInput
					on: #input of: self.
				html submitButton ] ].
		
	html definitionList: [
		html definitionTerm: 'Input'.
		html definitionData: self input.
		
		html definitionTerm: 'Parameter'.
		html definitionData: self parameter.
		
		html definitionTerm: 'Path'.
		html definitionData: self path ]! !

!WAUrlEncodingFunctionalTest methodsFor: 'rendering' stamp: 'pmm 12/5/2009 12:01'!
renderExplanationOn: html
	html paragraph: 'This tests whether url encoding works.'.
	html unorderedList: [
		html listItem: [
			html text: 'Go to the '.
			html anchor
				url: 'http://www.columbia.edu/kermit/utf8.html';
				with: 'UTF-8 Sampler'.
			html text: ' and select some "foreign" text.' ].
		html listItem: 'Copy and paste it into the urlencoded text field below and click the submit button.'.
		html listItem: 'The text should be displayed below "Input", "Parameter" and "Path" without any error.'.
		html listItem: 'The text may appear in the address bar of the browser.'.
		html listItem: 'Repeat this process. Make sure to pick at least every of these languages: German, Czech, Korean.' ]! !

!WAUrlEncodingFunctionalTest methodsFor: 'updating' stamp: 'jf 2/15/2010 02:08'!
updateUrl: aUrl
	super updateUrl: aUrl.
	input isEmptyOrNil ifTrue: [ ^ self ].
	aUrl addToPath: input.
	aUrl addField: 'input' value: input! !

WAFunctionalTest subclass: #WAValidationDecorationFunctionalTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAValidationDecorationFunctionalTest methodsFor: 'rendering' stamp: 'pmm 12/19/2010 17:22'!
renderContentOn: html
	self renderExplanationOn: html.
	self renderValidationOn: html! !

!WAValidationDecorationFunctionalTest methodsFor: 'rendering' stamp: 'pmm 12/19/2010 17:37'!
renderExplanationOn: html
	html paragraph: [
		html text: 'This is a functional test for WAValidationDecoration.'.
		html orderedList: [
			html listItem: 'Clicking on ''Start'' should take you to a new page with two links, "Fail validation" and "Suceed validation"'.
			html listItem: 'Clicking on "Fail validation" should display "Validation Failed!!" above the two links'.
			html listItem: 'Clicking on "Suceed validation" should just display "Validation Suceeded!!" and then take you back to this page' ] ]! !

!WAValidationDecorationFunctionalTest methodsFor: 'rendering' stamp: 'pmm 12/19/2010 17:34'!
renderValidationOn: html
	html anchor
		callback: [
			self call: (WAValidationTestComponent new
				validateWith: [ :value |
					value ifFalse: [
						WAValidationNotification signal: 'Validation Failed!!' ]];
				yourself).
			self inform: 'Validation Suceeded!!' ];
		with: 'Start'! !

WAComponent subclass: #WAInputElementContainer
	instanceVariableNames: 'textInput textArea singleSelection singleSelectionOptional singleSelectionCustom multiSelection nestedSelection nestedMultiSelection checkbox radio upload hiddenInput radioCustom'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAInputElementContainer methodsFor: 'accessing' stamp: 'pmm 9/19/2007 06:48'!
elements
	^ #( Quito Dakar Sydney Bamako )! !

!WAInputElementContainer methodsFor: 'accessing' stamp: 'pmm 9/19/2007 06:48'!
nestedElements
	^ #(('Functional' ('Haskell ' 'Lisp' 'ML')) ('Dataflow' ('Hartmann pipelines' 'G' 'Max' 'Prograph')) ('Fourth-generation' ('Today' 'Ubercode' 'Uniface')))! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'lr 12/27/2008 17:39'!
renderCheckboxOn: html
	self
		renderLabel: 'Checkbox'
		input: [
			html label: [
				html checkbox
					value: checkbox;
					callback: [ :value | checkbox := value ].
				html text: 'Checked' ] ]
		output: checkbox printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering' stamp: 'TestRunner 1/25/2010 11:14'!
renderContentOn: html
	self renderHeadingOn: html.
	self renderTextInputOn: html.
	self renderTextAreaOn: html.
	self renderHiddenInputOn: html.
	self renderCheckboxOn: html.
	self renderRadioButtonsOn: html.
	self renderRadioButtonsCustomOn: html.
	self renderSingleSelectionOn: html.
	self renderSingleSelectionCustomOn: html.
	self renderSingleSelectionOptionalOn: html.
	self renderMultiSelectionOn: html.
	self renderNestedSelectionOn: html.
	self renderNestedMultiSelectionOn: html.
	self renderUploadOn: html! !

!WAInputElementContainer methodsFor: 'rendering' stamp: 'lr 12/27/2008 17:29'!
renderHeadingOn: html
	html tableRow: [
		html tableHeading.
		html tableHeading: 'Control'.
		html tableHeading: 'Print String' ]! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'lr 2/22/2009 15:25'!
renderHiddenInputOn: html
	| string |
	string := hiddenInput ifNil: [ 'Seaside' ].
	self
		renderLabel: 'Hidden Input'
		input: [
			html render: string.			
			html hiddenInput
				value: string;
				callback: [ :value | hiddenInput := value ] ]
		output: hiddenInput printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering' stamp: 'pmm 9/19/2007 06:48'!
renderLabel: aString input: anInputBlock output: anOutputBlock on: html
	html tableRow: [
		html tableHeading: aString.
		html tableData: anInputBlock.
		html tableData: anOutputBlock ]! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'pmm 6/26/2011 14:11'!
renderMultiSelectionOn: html 
	self 
		renderLabel: 'Multi Selection'
		input: [
			html multiSelect
				list: self elements;
				titles: [ :each | 'Title: ' , each greaseString ];
				selected: multiSelection;
				callback: [ :value | multiSelection := value ] ]
		output: [
			multiSelection isEmptyOrNil ifFalse: [
				"empty lists are invalid HTML"
				html unorderedList list: multiSelection ] ]
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'obi 1/1/2010 10:03'!
renderNestedMultiSelectionOn: html
	| selectTag |
	self
		renderLabel: 'Nested Multi Selection'
		input: [
			selectTag := html multiSelect.
			selectTag
				size: 6;
				callback: [:value | nestedMultiSelection := value ];
				selected: nestedMultiSelection;
				with: [
					self nestedElements do: [ :list |
						html optionGroup
							label: list first;
							with: [
								list second do: [ :each |
									html option
										value: each with: selectTag ;
										with: each ] ] ] ] ]
		output: [ nestedMultiSelection isNil ifFalse: [ html unorderedList list: nestedMultiSelection ] ]
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'obi 1/1/2010 10:03'!
renderNestedSelectionOn: html
	| selectTag |
	self
		renderLabel: 'Nested Selection'
		input: [
			selectTag := html select.
			selectTag
				callback: [:value | nestedSelection := value ];
				selected: nestedSelection;
				with: [
					self nestedElements do: [ :list |
						html optionGroup
							label: list first;
							with: [
								list second do: [ :each |
									html option
										value: each with: selectTag;
										with: each ] ] ] ] ]
		output: nestedSelection printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'TestRunner 1/25/2010 11:13'!
renderRadioButtonsCustomOn: html
	self
		renderLabel: 'Radiogroup (Custom)'
		input: [
			html radioGroup: [ :group |
					self elements do: [ :each |
						html label: [ 
							html radioButton
								group: group;
								selected: radioCustom = each;
								callback: [ radioCustom := each ].
							html text: each ].
						html break ] ] ]
		output: radioCustom printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'TestRunner 1/25/2010 11:14'!
renderRadioButtonsOn: html
	self
		renderLabel: 'Radiogroup'
		input: [
			html radioGroup
				callback: [:value | radio := value];
				selected: radio;
				with: [ :group |
					self elements do: [ :each |
						html label: [ 
							group radioButton value: each.
							html text: each ].
						html break ] ] ]
		output: radio printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'lr 1/23/2010 14:06'!
renderSingleSelectionCustomOn: html 
	self 
		renderLabel: 'Single Selection (Custom)'
		input: [
			html select
				dispatchCallback;
				with: [
					self elements do: [ :each |
						html option
							label: 'Short: ' , (each copyFrom: 1 to: 3);
							callback: [ singleSelectionCustom := each ];
							selected: (singleSelectionCustom = each);
							with: 'Custom:' , each greaseString  ] ] ]
		output: singleSelectionCustom printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'pmm 6/26/2011 14:12'!
renderSingleSelectionOn: html 
	self 
		renderLabel: 'Single Selection'
		input: [
			html select
				list: self elements;
				titles: [ :each | 'Title: ' , each greaseString ];
				selected: singleSelection;
				callback: [ :value | singleSelection := value ] ]
		output: singleSelection printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'lr 10/28/2007 14:42'!
renderSingleSelectionOptionalOn: html
	self
		renderLabel: 'Single Selection (Optional)'
		input: [
			html select
				beOptional;
				list: self elements;
				optionalLabel: '(none)';
				selected: singleSelectionOptional;
				callback: [ :value | singleSelectionOptional := value ] ]
		output: singleSelectionOptional printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'lr 12/27/2008 17:38'!
renderTextAreaOn: html
	self
		renderLabel: 'Text Area'
		input: [
			html textArea
				rows: 3;
				columns: 17;
				value: textArea;
				callback: [ :value | textArea := value ] ]
		output: textArea printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'lr 12/27/2008 17:38'!
renderTextInputOn: html
	self
		renderLabel: 'Text Input'
		input: [
			html textInput
				value: textInput;
				callback: [ :value | textInput := value ] ]
		output: textInput printString
		on: html! !

!WAInputElementContainer methodsFor: 'rendering-elements' stamp: 'lr 2/22/2009 15:08'!
renderUploadOn: html
	self
		renderLabel: 'Upload'
		input: [ html fileUpload callback: [ :file | upload := file ] ]
		output: upload printString
		on: html! !

WAComponent subclass: #WAPopupCloseTestComponent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAPopupCloseTestComponent methodsFor: 'rendering' stamp: 'lr 7/25/2011 18:56'!
renderContentOn: html
	html anchor
		callback: [ self requestContext closeThisPopup ];
		with: 'Close me'.
	html break.
	html anchor
		callback: [ self requestContext closeThisPopupAndReloadOpener ];
		with: 'Close me and reload opener'! !

WAComponent subclass: #WATrailTestComponent
	instanceVariableNames: 'count'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WATrailTestComponent methodsFor: 'accessing' stamp: 'jf 11/4/2008 11:39'!
count: aNumber
	count := aNumber! !

!WATrailTestComponent methodsFor: 'initialization' stamp: 'jf 11/4/2008 11:42'!
initialize
	super initialize.
	count := 1! !

!WATrailTestComponent methodsFor: 'rendering' stamp: 'lr 1/24/2009 21:11'!
renderContentOn: html
	html heading
		level: 1;
		with: self trailName.

	html anchor
		callback: [ self show: (self class new count: count+1; yourself) ];
		with: 'Call'.
		
	html space.
		
	html anchor
		callback: [ self answer ];
		with: 'Answer'! !

!WATrailTestComponent methodsFor: 'accessing' stamp: 'jf 9/30/2009 01:10'!
trailName
	^ 'Item ' , count greaseString , ' (' , self identityHash greaseString , ')'! !

WAComponent subclass: #WAValidationTestComponent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAValidationTestComponent methodsFor: 'rendering' stamp: 'pmm 12/19/2010 17:34'!
renderContentOn: html
	html anchor
		callback: [
			self answer: false ];
		with: 'Fail validation'.
	html break.
	html anchor
		callback: [
			self answer: true ];
		with: 'Suceed validation'.! !

TestCase subclass: #WATestsFunctionalPlatformTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WATestsFunctionalPlatformTest methodsFor: 'tests' stamp: 'jf 2/9/2010 01:29'!
testGarbageCollect
	self 
		shouldnt: [ GRPlatform current seasideGarbageCollect ]
		raise: MessageNotUnderstood! !

WASession subclass: #WAExpirySession
	instanceVariableNames: ''
	classVariableNames: 'Created Unregistered'
	poolDictionaries: ''
	category: 'Seaside-Tests-Functional'!

!WAExpirySession class methodsFor: 'accessing' stamp: 'avi 9/30/2004 16:30'!
created
	^ Created! !

!WAExpirySession class methodsFor: 'class initialization' stamp: 'avi 9/30/2004 16:24'!
initialize
	self resetCounters! !

!WAExpirySession class methodsFor: 'actions' stamp: 'lr 10/28/2007 14:42'!
resetCounters
	Unregistered := 0.
	Created := 0! !

!WAExpirySession class methodsFor: 'accessing' stamp: 'avi 9/30/2004 16:30'!
unregistered
	^ Unregistered! !

!WAExpirySession methodsFor: 'initialization' stamp: 'avi 9/30/2004 16:24'!
initialize
	super initialize.
	Created := Created + 1! !

!WAExpirySession methodsFor: 'parent/child' stamp: 'lr 2/12/2007 19:37'!
unregistered
	super unregistered.
	Unregistered := Unregistered + 1! !
WAAllFunctionalTests initialize!
WAExpirySession initialize!
